(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    124042,       2510]
NotebookOptionsPosition[    121300,       2463]
NotebookOutlinePosition[    121667,       2479]
CellTagsIndexPosition[    121624,       2476]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Off", "[", 
    RowBox[{"General", "::", "spell1"}], "]"}], ";", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "ncvb"}], "]"}], ";", 
   RowBox[{"Off", "[", 
    RowBox[{"NIntegrate", "::", "slwcon"}], "]"}]}], 
  RowBox[{"(*", 
   RowBox[{"Block", " ", "unnecessary", " ", "error", " ", "messages"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Needs", "[", "\"\<ErrorBarPlots`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "V", ",", "dV", ",", "t", ",", " ", "p", ",", "pwr", ",", "pws", ",", 
    "pwt", ",", "dys", ",", "AxisTick", ",", "param", ",", "\[Sigma]", ",", 
    "\[Mu]", ",", "PB", ",", "P", ",", "A", ",", "mx", ",", "solveFPE", ",", 
    "eq", ",", "Persist"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["V", "min"], " ", "=", " ", "0.01"}], ";"}], "    ", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"The", " ", "minimal", " ", "size", " ", "of", " ", "spines"}], 
    "*)"}],
   FontColor->RGBColor[0, 0, 1]]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["V", "max"], " ", "=", " ", "1"}], ";"}], "          ", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"The", " ", "maximal", " ", "size", " ", "of", " ", "spines"}], 
    "*)"}],
   FontColor->RGBColor[0, 0, 1]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"WT", "=", "1"}], ";", " ", 
   RowBox[{"KO", "=", "2"}], ";", " ", 
   RowBox[{"fast", "=", "3"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"Spine", " ", "Dynamics"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Ideal", " ", 
     RowBox[{"parameters", ":", " ", 
      RowBox[{"SD", " ", 
       RowBox[{"(", 
        RowBox[{"\[Sigma]", ",", " ", 
         RowBox[{
          SuperscriptBox["\[Mu]m", "3"], 
          SuperscriptBox["day", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}]]}]}], ")"}], "and", " ", "drift", 
       " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", ",", " ", 
         RowBox[{
          SuperscriptBox["\[Mu]m", "3"], 
          SuperscriptBox["day", 
           RowBox[{"-", "1"}]]}]}], ")"}]}]}]}], "*)"}]}],
  FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"param", "=", "WT"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Parameter", " ", "chosen", " ", "for", " ", "simulation"}], 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "param", "]"}], "[", "V_", "]"}], " ", ":=", 
   "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0.1976", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"2", "/", "3"}]], "-", "0.06"}], ")"}]}], "+", "0.020"}], 
     ")"}], "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", "[", "param", "]"}], "[", "V_", "]"}], " ", ":=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.12"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"2", "/", "3"}]], "-", 
         SuperscriptBox["0.12", 
          RowBox[{"2", "/", "3"}]]}], ")"}]}], ")"}], "/", "2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"param", "=", "KO"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Parameter", " ", "chosen", " ", "for", " ", "simulation"}], 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "param", "]"}], "[", "V_", "]"}], " ", ":=", 
   "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0.2778", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"2", "/", "3"}]], "-", "0.06"}], ")"}]}], "+", "0.020"}], 
     ")"}], "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", "[", "param", "]"}], "[", "V_", "]"}], " ", ":=", "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.12"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"2", "/", "3"}]], "-", 
         SuperscriptBox["0.12", 
          RowBox[{"2", "/", "3"}]]}], ")"}]}], ")"}], "/", "2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"param", "=", "fast"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"Parameter", " ", "chosen", " ", "for", " ", "simulation"}], 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "param", "]"}], "[", "V_", "]"}], " ", ":=", 
   "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0.1151", 
       SuperscriptBox["V", 
        RowBox[{"2", "/", "3"}]]}], "+", "0.005117"}], ")"}], "/", 
    RowBox[{"Sqrt", "[", "2", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", "[", "param", "]"}], "[", "V_", "]"}], " ", ":=", "  ", 
    RowBox[{"0", "/", "2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
    RowBox[{"Spine", " ", "Dynamics"}], ";"}],
   FontColor->RGBColor[0, 0, 1]], " ", 
  StyleBox[
   RowBox[{"(*", 
    RowBox[{"Stationary", " ", "distribution"}], "*)"}],
   FontColor->RGBColor[0, 0, 1]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PB", "[", 
    RowBox[{"para_", ",", 
     RowBox[{"V_", "?", "NumberQ"}]}], "]"}], ":=", 
   RowBox[{
    FractionBox["2", 
     SuperscriptBox[
      RowBox[{
       RowBox[{"\[Sigma]", "[", "para", "]"}], "[", "V", "]"}], "2"]], 
    RowBox[{"Exp", "[", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          RowBox[{"\[Mu]", "[", "para", "]"}], "[", "v", "]"}]}], 
        SuperscriptBox[
         RowBox[{
          RowBox[{"\[Sigma]", "[", "para", "]"}], "[", "v", "]"}], "2"]], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", "Vmin", ",", "V"}], "}"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "4"}]}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"P", "[", 
     RowBox[{"para_", ",", "V_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"PB", "[", 
      RowBox[{"para", ",", "V"}], "]"}], "/", 
     RowBox[{"NC", "[", 
      RowBox[{"[", "para", "]"}], "]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Probability", " ", "density", " ", "of", " ", "spines", " ", "whose", " ",
     "volumes", " ", "are", " ", "V", 
    RowBox[{"(", 
     SuperscriptBox["\[Mu]m", "3"], ")"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"Spine", " ", "Dynamics"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Spine", "-", 
     RowBox[{
     "volume", " ", "compartments", " ", "used", " ", "for", " ", "Fokker"}], 
     "-", 
     RowBox[{"Planck", " ", "equation", " ", "and", " ", "Monte"}], "-", 
     RowBox[{"Carlo", " ", "methods"}]}], "*)"}]}],
  FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"A", "[", "i_", "]"}], ":=", 
    RowBox[{
     SubscriptBox["V", "min"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"i", "-", "0.5"}], ")"}], " ", "dV"}]}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Average", " ", "volume", " ", "of", " ", "the", " ", "ith", " ", 
    "compartment"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mx", ":=", 
    RowBox[{"Floor", "[", 
     FractionBox[
      RowBox[{
       SubscriptBox["V", "max"], "-", 
       SubscriptBox["V", "min"]}], "dV"], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", "compartments"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ProbDensOrdinate", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "8.2"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vmin", "=", 
   SubscriptBox["V", "min"]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Vmax", "=", 
    SubscriptBox["V", "max"]}], " ", ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"Spine", " ", "Dynamics"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Fokker", "-", 
     RowBox[{"Planck", " ", "equation"}]}], "*)"}]}],
  FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"solveFPE", "[", 
    RowBox[{
    "s_", ",", " ", "d_", ",", " ", "init_", ",", "timespan_", ",", " ", 
     "boundary_"}], "]"}], " ", ":=", "\[IndentingNewLine]", " ", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", "\t", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{"eq", ",", " ", "eqns", ",", " ", "func"}], " ", "}"}], ",", 
     "\[IndentingNewLine]", "\t", 
     RowBox[{
      RowBox[{
       RowBox[{"eq", "[", "i_", "]"}], ":=", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "i", "]"}], "[", "t", "]"}], ",", "t"}], "]"}], 
        "\[Equal]", " ", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox[
             RowBox[{"s", "[", 
              RowBox[{"A", "[", 
               RowBox[{"i", "+", "1"}], "]"}], "]"}], "2"], 
            RowBox[{
             RowBox[{"p", "[", 
              RowBox[{"i", "+", "1"}], "]"}], "[", "t", "]"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"s", "[", 
              RowBox[{"A", "[", "i", "]"}], "]"}], "2"], 
            RowBox[{
             RowBox[{"p", "[", "i", "]"}], "[", "t", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"s", "[", 
              RowBox[{"A", "[", 
               RowBox[{"i", "-", "1"}], "]"}], "]"}], "2"], 
            RowBox[{
             RowBox[{"p", "[", 
              RowBox[{"i", "-", "1"}], "]"}], "[", "t", "]"}]}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["dV", "2"]}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"A", "[", 
              RowBox[{"i", "+", "1"}], "]"}], "]"}], 
            RowBox[{
             RowBox[{"p", "[", 
              RowBox[{"i", "+", "1"}], "]"}], "[", "t", "]"}]}], "-", 
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"A", "[", 
              RowBox[{"i", "-", "1"}], "]"}], "]"}], 
            RowBox[{
             RowBox[{"p", "[", 
              RowBox[{"i", "-", "1"}], "]"}], "[", "t", "]"}]}]}], 
          RowBox[{"2", " ", "dV"}]]}]}]}], ";", "\[IndentingNewLine]", "\t", 
      RowBox[{
       RowBox[{"eq", "[", "mx", "]"}], ":=", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "mx", "]"}], "[", "t", "]"}], ",", "t"}], "]"}], 
        "\[Equal]", " ", 
        RowBox[{
         FractionBox[
          RowBox[{" ", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"s", "[", 
               RowBox[{"A", "[", 
                RowBox[{"mx", "-", "1"}], "]"}], "]"}], "2"], 
             RowBox[{
              RowBox[{"p", "[", 
               RowBox[{"mx", "-", "1"}], "]"}], "[", "t", "]"}]}], "-", " ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"s", "[", 
               RowBox[{"A", "[", "mx", "]"}], "]"}], "2"], 
             RowBox[{
              RowBox[{"p", "[", "mx", "]"}], "[", "t", "]"}]}]}]}], 
          RowBox[{"2", 
           SuperscriptBox["dV", "2"]}]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"d", "[", 
              RowBox[{"A", "[", "mx", "]"}], "]"}]}], 
            RowBox[{
             RowBox[{"p", "[", "mx", "]"}], "[", "t", "]"}]}], "-", " ", 
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"A", "[", 
              RowBox[{"mx", "-", "1"}], "]"}], "]"}], 
            RowBox[{
             RowBox[{"p", "[", 
              RowBox[{"mx", "-", "1"}], "]"}], "[", "t", "]"}]}]}], 
          RowBox[{"2", " ", "dV"}]]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"eq", "[", "1", "]"}], ":=", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "1", "]"}], "[", "t", "]"}], ",", "t"}], "]"}], "==",
         " ", "\[IndentingNewLine]", "\t", 
        RowBox[{"Which", "[", "\[IndentingNewLine]", "\t\t", 
         RowBox[{
          RowBox[{"boundary", "\[Equal]", "1"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{"  ", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"s", "[", 
                 RowBox[{"A", "[", "2", "]"}], "]"}], "2"], 
               RowBox[{
                RowBox[{"p", "[", "2", "]"}], "[", "t", "]"}]}], "-", "  ", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"s", "[", 
                 RowBox[{"A", "[", "1", "]"}], "]"}], "2"], 
               RowBox[{
                RowBox[{"p", "[", "1", "]"}], "[", "t", "]"}]}]}]}], 
            RowBox[{"2", 
             SuperscriptBox["dV", "2"]}]], "-", 
           FractionBox[
            RowBox[{
             RowBox[{
              RowBox[{"d", "[", 
               RowBox[{"A", "[", "2", "]"}], "]"}], 
              RowBox[{
               RowBox[{"p", "[", "2", "]"}], "[", "t", "]"}]}], "+", " ", 
             RowBox[{
              RowBox[{"d", "[", 
               RowBox[{"A", "[", "1", "]"}], "]"}], 
              RowBox[{
               RowBox[{"p", "[", "1", "]"}], "[", "t", "]"}]}]}], 
            RowBox[{"2", " ", "dV"}]]}], ",", 
          StyleBox[
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Reflecting", " ", "boundary", " ", "at", " ", "V"}], 
             "=", 
             SubscriptBox["V", "min"]}], "**)"}],
           FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", "\t\t", 
          RowBox[{"boundary", "\[Equal]", "2"}], ",", " ", 
          RowBox[{
           FractionBox[
            RowBox[{"  ", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"s", "[", 
                 RowBox[{"A", "[", "2", "]"}], "]"}], "2"], 
               RowBox[{
                RowBox[{"p", "[", "2", "]"}], "[", "t", "]"}]}], "-", " ", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"s", "[", 
                 RowBox[{"A", "[", "1", "]"}], "]"}], "2"], 
               RowBox[{
                RowBox[{"p", "[", "1", "]"}], "[", "t", "]"}]}]}]}], 
            RowBox[{"2", 
             SuperscriptBox["dV", "2"]}]], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"A", "[", "2", "]"}], "]"}], 
             RowBox[{
              RowBox[{"p", "[", "2", "]"}], "[", "t", "]"}]}], 
            RowBox[{"2", " ", "dV"}]]}], ",", 
          StyleBox[
           RowBox[{"(*", 
            RowBox[{
             RowBox[{"Absorbing", " ", "boundary", " ", "at", " ", "V"}], "=", 
             SubscriptBox["V", "min"]}], "*)"}],
           FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", "\t\t", 
          RowBox[{"boundary", "\[Equal]", "3"}], ",", 
          RowBox[{
           FractionBox[
            RowBox[{"  ", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                RowBox[{"s", "[", 
                 RowBox[{"A", "[", "2", "]"}], "]"}], "2"], 
               RowBox[{
                RowBox[{"p", "[", "2", "]"}], "[", "t", "]"}]}], "-", " ", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"s", "[", 
                 RowBox[{"A", "[", "1", "]"}], "]"}], "2"], 
               RowBox[{
                RowBox[{"p", "[", "1", "]"}], "[", "t", "]"}]}]}]}], 
            RowBox[{"2", 
             SuperscriptBox["dV", "2"]}]], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"A", "[", "2", "]"}], "]"}], 
             RowBox[{
              RowBox[{"p", "[", "2", "]"}], "[", "t", "]"}]}], 
            RowBox[{"2", " ", "dV"}]], "+", 
           RowBox[{"new", "[", "t", "]"}]}]}], 
         StyleBox[
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Absorbing", " ", "boundary", " ", "at", " ", "V"}], "=", 
            RowBox[{
             SubscriptBox["V", "min"], " ", "and", " ", "continuously", " ", 
             "generating", " ", "spines"}]}], "*)"}],
          FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", "\t", 
         "]"}]}]}], " ", ";", "\[IndentingNewLine]", "\t", 
      RowBox[{"eqns", " ", "=", " ", 
       RowBox[{"Array", "[", 
        RowBox[{"eq", ",", " ", "mx"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{"func", " ", "=", " ", 
       RowBox[{"Array", "[", 
        RowBox[{"p", ",", " ", "mx"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\t", 
      RowBox[{"sol1", "=", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"eqns", ",", " ", "init"}], "}"}], ",", " ", "func", ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"t", ",", " ", "0", ",", " ", "timespan"}], "}"}]}], 
        "]"}]}]}]}], 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"Solution", " ", "of", " ", "Fokker"}], "-", 
      RowBox[{"Planck", " ", "equation"}]}], "*)"}], "\[IndentingNewLine]", 
    "]"}]}], " ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Length", "[", "NC", "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{"NC", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", "5"}], "]"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NC", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"NC", ",", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"WT", ",", "KO", ",", "fast"}], "]"}], "-", 
           RowBox[{"Length", "[", "NC", "]"}]}], ",", "0"}], "]"}]}], "]"}]}],
      "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NC", "[", 
    RowBox[{"[", "WT", "]"}], "]"}], "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"PB", "[", 
      RowBox[{"WT", ",", "V"}], "]"}], ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{"V", ",", 
       SubscriptBox["V", "min"], ",", 
       SubscriptBox["V", "max"]}], " ", "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NC", "[", 
    RowBox[{"[", "KO", "]"}], "]"}], "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"PB", "[", 
      RowBox[{"KO", ",", "V"}], "]"}], ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{"V", ",", 
       SubscriptBox["V", "min"], ",", 
       SubscriptBox["V", "max"]}], " ", "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NC", "[", 
    RowBox[{"[", "fast", "]"}], "]"}], "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"PB", "[", 
      RowBox[{"fast", ",", "V"}], "]"}], ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{"V", ",", 
       SubscriptBox["V", "min"], ",", 
       SubscriptBox["V", "max"]}], " ", "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.44400585840625*^9, 3.444005866578125*^9}, 
   3.44400665846875*^9, {3.444014507171875*^9, 3.44401473825*^9}, {
   3.444014785375*^9, 3.44401481415625*^9}, {3.444020909125*^9, 
   3.444020913140625*^9}, {3.444021034671875*^9, 3.444021036*^9}, {
   3.444021071328125*^9, 3.444021072234375*^9}, {3.4440882610625*^9, 
   3.44408832740625*^9}, {3.444088365171875*^9, 3.44408837271875*^9}, {
   3.444088423171875*^9, 3.4440884310625*^9}, {3.444088485375*^9, 
   3.444088496875*^9}, 3.444089123625*^9, {3.444093767015625*^9, 
   3.444093941*^9}, 3.44409405671875*^9, 3.44412694215625*^9, {
   3.4442199669375*^9, 3.44422004159375*^9}, {3.4442200815625*^9, 
   3.444220234359375*^9}, {3.444220304296875*^9, 3.444220306078125*^9}, 
   3.444354716106393*^9, {3.4443556131532683`*^9, 3.4443556356845183`*^9}, {
   3.4443617900282683`*^9, 3.4443618117470183`*^9}, {3.444362814075143*^9, 
   3.4443628319032683`*^9}, {3.44462286840625*^9, 3.444622888875*^9}, {
   3.444624516*^9, 3.444624516828125*^9}, {3.444625264359375*^9, 
   3.44462526915625*^9}, {3.69791254152815*^9, 3.697912648766345*^9}, {
   3.6979126825204077`*^9, 3.6979128475127993`*^9}, {3.6979129095749846`*^9, 
   3.6979129658311157`*^9}, {3.6979130060673094`*^9, 
   3.6979130466474237`*^9}, {3.6979145323676343`*^9, 
   3.6979145998257976`*^9}, {3.697915719505581*^9, 3.6979157622317104`*^9}, {
   3.697916570977154*^9, 3.6979165714391556`*^9}, {3.6979166466279116`*^9, 
   3.6979166471699142`*^9}, {3.6979167163673587`*^9, 3.697916717445365*^9}, {
   3.6979171558751135`*^9, 3.697917207173314*^9}, {3.697917373571504*^9, 
   3.697917374053506*^9}, {3.6979183691387706`*^9, 3.6979183702107735`*^9}, {
   3.697918492879071*^9, 3.6979186219173994`*^9}, {3.697918753532446*^9, 
   3.6979187541144485`*^9}, {3.6979193180375834`*^9, 3.697919577274209*^9}, {
   3.6979198716528363`*^9, 3.6979198721948385`*^9}, {3.697921444193293*^9, 
   3.6979214599053698`*^9}, {3.6979215762901497`*^9, 3.697921612758748*^9}, {
   3.6979218807861967`*^9, 3.6979219626543703`*^9}, {3.69792229836968*^9, 
   3.6979222990136833`*^9}, {3.697923273560886*^9, 3.6979234351438017`*^9}, {
   3.6979234654998484`*^9, 3.6979234706338654`*^9}, {3.697923501651944*^9, 
   3.6979235573560653`*^9}, {3.6979235886341343`*^9, 
   3.6979236970644255`*^9}, {3.697926424559084*^9, 3.6979266060923824`*^9}, {
   3.697998345878227*^9, 3.6979984820026054`*^9}, {3.6979985506249056`*^9, 
   3.6979985511789093`*^9}, {3.697999593309049*^9, 3.6979995937410517`*^9}, {
   3.698002171587996*^9, 3.6980021748560076`*^9}, 3.6980040782948303`*^9, {
   3.6980042545683365`*^9, 3.6980042547723475`*^9}, {3.6980047781902857`*^9, 
   3.6980047810934515`*^9}, {3.698005226052874*^9, 3.698005246422039*^9}, {
   3.6980066324838753`*^9, 3.698006634339884*^9}, {3.698007021147705*^9, 
   3.6980070217997084`*^9}, {3.699046620505639*^9, 3.699046647963888*^9}, {
   3.699046690426051*^9, 3.6990467968589425`*^9}, {3.6990470138597164`*^9, 
   3.699047103597761*^9}, {3.6990472736573067`*^9, 3.6990472784433384`*^9}, {
   3.6990474804461565`*^9, 3.699047554696476*^9}, {3.699047652138377*^9, 
   3.699047653162385*^9}, {3.6990477313651733`*^9, 3.6990477325411897`*^9}, {
   3.699047802737723*^9, 3.699047811073763*^9}, {3.699047918510536*^9, 
   3.699047937474612*^9}, {3.6990481471318383`*^9, 3.699048224420504*^9}, {
   3.6990483743587275`*^9, 3.6990483810147667`*^9}, {3.699048545565157*^9, 
   3.699048567459232*^9}, {3.699048657707752*^9, 3.699048694637961*^9}, {
   3.699048837445836*^9, 3.6990488406438637`*^9}, {3.699048953690429*^9, 
   3.6990489542024355`*^9}, {3.699049409937463*^9, 3.699049469221779*^9}, {
   3.699049562234227*^9, 3.699049568956293*^9}, {3.6990496789017797`*^9, 
   3.699049679843787*^9}, {3.6990497107978907`*^9, 3.6990497125419006`*^9}, {
   3.699049788432094*^9, 3.6990498156932*^9}, {3.699049932509097*^9, 
   3.699049933231105*^9}, {3.699050110921976*^9, 3.6990501114839835`*^9}, {
   3.6990502074546914`*^9, 3.6990502261447954`*^9}, {3.699050368981956*^9, 
   3.699050398181066*^9}, {3.699050541879321*^9, 3.6990505491513863`*^9}, {
   3.699050750714658*^9, 3.699050751570674*^9}, {3.6990550781448298`*^9, 
   3.6990551404473925`*^9}, {3.6990555405203*^9, 3.6990555413913493`*^9}, {
   3.699055612655425*^9, 3.6990556160476193`*^9}, {3.6990556502361517`*^9, 
   3.6990556507581615`*^9}, {3.6990557219526234`*^9, 
   3.6990557277326612`*^9}, {3.6990558222713203`*^9, 3.699055826838581*^9}, {
   3.699056087407865*^9, 3.699056088697899*^9}, {3.699056783343195*^9, 
   3.6990567923032527`*^9}, {3.699056960071842*^9, 3.699056961145856*^9}, {
   3.699057117523349*^9, 3.699057124815381*^9}, {3.6990573415698433`*^9, 
   3.6990573652230315`*^9}, {3.6990575056174526`*^9, 
   3.6990575067014728`*^9}, {3.6990576467778406`*^9, 
   3.6990576542208986`*^9}, {3.6990582861770353`*^9, 3.699058308159213*^9}, {
   3.6990584305628233`*^9, 3.6990584375369153`*^9}, {3.699058665846833*^9, 
   3.6990587202852297`*^9}, 3.699058962962763*^9, {3.699059032533142*^9, 
   3.699059128911892*^9}, {3.6990592239965596`*^9, 3.6990592366246853`*^9}, {
   3.699059285741021*^9, 3.699059337046483*^9}, {3.699059489306922*^9, 
   3.699059489878936*^9}, {3.6990595530473547`*^9, 3.6990595553203993`*^9}, {
   3.699059761772339*^9, 3.699059766034403*^9}, {3.699059816216564*^9, 
   3.699059835800722*^9}, {3.699060189001723*^9, 3.6990602292730985`*^9}, {
   3.6990603974113665`*^9, 3.699060403851427*^9}, {3.6990605795774317`*^9, 
   3.6990605808294463`*^9}, {3.6990607410433283`*^9, 
   3.6990607444813924`*^9}, {3.6990607794023447`*^9, 3.699060795499265*^9}, {
   3.699061060565729*^9, 3.6990610987062435`*^9}, {3.699061133794369*^9, 
   3.699061135694412*^9}, {3.699061278967812*^9, 3.6990613452225513`*^9}, {
   3.6990615538215237`*^9, 3.6990616093179235`*^9}, {3.699061889993952*^9, 
   3.6990619117203517`*^9}, {3.6990622318323975`*^9, 3.699062266264805*^9}, {
   3.6990623053630652`*^9, 3.699062341187359*^9}, {3.699062545692301*^9, 
   3.6990625638694763`*^9}, {3.699062965963894*^9, 3.6990629699659595`*^9}, {
   3.699063007050288*^9, 3.6990630214324665`*^9}, {3.69906313158704*^9, 
   3.6990631839375753`*^9}, {3.699063281259612*^9, 3.6990632815286255`*^9}, 
   3.6990634659532743`*^9, {3.6990636060196376`*^9, 3.6990636070136557`*^9}, {
   3.699065740134189*^9, 3.6990658109646378`*^9}, {3.699065844506735*^9, 
   3.6990658650688243`*^9}, {3.699066047726859*^9, 3.699066126277179*^9}, {
   3.6990663746517324`*^9, 3.699066429699931*^9}, {3.699066541653967*^9, 
   3.6990665630300484`*^9}, {3.699066875566324*^9, 3.699066884724742*^9}, {
   3.6990696031561193`*^9, 3.6990696048361335`*^9}, 3.6990696392423573`*^9, {
   3.6990703316718435`*^9, 3.6990703416698914`*^9}, 3.6990706923513236`*^9, {
   3.699070910696806*^9, 3.6990709115588083`*^9}, 3.6990719326685767`*^9, {
   3.6990719982795043`*^9, 3.699072041160199*^9}, {3.6990722874151826`*^9, 
   3.69907231841534*^9}, {3.6990724368707466`*^9, 3.6990724617187347`*^9}, {
   3.699072618960602*^9, 3.699072619511633*^9}, {3.6990727663209543`*^9, 
   3.6990727667899604`*^9}, {3.699072908523863*^9, 3.6990729162148943`*^9}, {
   3.699073004658869*^9, 3.6990730495666056`*^9}, {3.6990733504117403`*^9, 
   3.6990734075598164`*^9}, {3.6990737079318786`*^9, 3.699073734207006*^9}, {
   3.699074342536166*^9, 3.699074396135131*^9}, {3.699074698465829*^9, 
   3.699074723896093*^9}, {3.6990747737128305`*^9, 3.699074774535878*^9}, {
   3.699075038772763*^9, 3.6990750609063673`*^9}, {3.69907521053909*^9, 
   3.6990752363916993`*^9}, {3.6990753875031137`*^9, 
   3.6990754094863024`*^9}, {3.6990762156387844`*^9, 
   3.6990762378358893`*^9}, {3.6990764291996593`*^9, 
   3.6990764293496666`*^9}, {3.6990768998181505`*^9, 
   3.6990769442044086`*^9}, {3.699077213022622*^9, 3.6990772805253787`*^9}, {
   3.6991309611972046`*^9, 3.699130990625364*^9}, {3.6991312163838196`*^9, 
   3.6991312169978285`*^9}, {3.69941122463287*^9, 3.699411339172166*^9}, {
   3.699411383596573*^9, 3.699411385716608*^9}, {3.6994115193081713`*^9, 
   3.699411523658247*^9}, {3.6994116062117805`*^9, 3.699411611687838*^9}, {
   3.699412568398634*^9, 3.699412589831868*^9}, {3.699413977104169*^9, 
   3.69941399084035*^9}, {3.6994141706166496`*^9, 3.6994142018449507`*^9}, 
   3.6994144017508554`*^9, {3.699415089296281*^9, 3.699415107925477*^9}, {
   3.699415212598227*^9, 3.6994152193702903`*^9}, {3.699416317177195*^9, 
   3.6994163263837214`*^9}, 3.6994168671764235`*^9, 3.6994173765295687`*^9, {
   3.699418090139989*^9, 3.699418174365915*^9}, {3.6994753487158155`*^9, 
   3.699475417488753*^9}, {3.699476415565323*^9, 3.699476422959409*^9}, {
   3.699476457527836*^9, 3.6994764726800237`*^9}, {3.6994765160384398`*^9, 
   3.6994765648609705`*^9}, {3.6994765999913187`*^9, 3.699476655645934*^9}, {
   3.699476961096856*^9, 3.699476961630872*^9}, {3.699476997997364*^9, 
   3.6994770033154306`*^9}, {3.6994771717842093`*^9, 
   3.6994772362633924`*^9}, {3.699477389036147*^9, 3.699477400792287*^9}, {
   3.699477476208596*^9, 3.699477598383298*^9}, {3.6994778606445217`*^9, 
   3.6994778695956397`*^9}, {3.699477909081493*^9, 3.6994779107380323`*^9}, {
   3.699478370580537*^9, 3.699478378361636*^9}, {3.6994787416712713`*^9, 
   3.699478873766677*^9}, {3.699479013337119*^9, 3.699479013895131*^9}, {
   3.6994793576462946`*^9, 3.699479455191394*^9}, {3.699479626950701*^9, 
   3.6994796696751723`*^9}, {3.6994798470006633`*^9, 
   3.6994799142554293`*^9}, {3.6994799469059105`*^9, 
   3.6994799613800735`*^9}, {3.699480086639432*^9, 3.699480145516096*^9}, {
   3.699480189757347*^9, 3.699480243737959*^9}, {3.6994803385198827`*^9, 
   3.699480346190321*^9}, {3.6994804009879274`*^9, 3.69948040862202*^9}, {
   3.6994807496272507`*^9, 3.699480798663844*^9}, {3.6994808451143026`*^9, 
   3.6994808456783075`*^9}, {3.6994810019766417`*^9, 3.699481068031377*^9}, {
   3.6994813124631643`*^9, 3.6994814149323645`*^9}, {3.699481604820015*^9, 
   3.699481610376087*^9}, {3.6994816648326454`*^9, 3.699481668788697*^9}, {
   3.6994817264482965`*^9, 3.69948183993513*^9}, {3.699481929182996*^9, 
   3.6994819628873587`*^9}, {3.699482040410777*^9, 3.699482042119785*^9}, {
   3.6994822108093653`*^9, 3.6994822608619103`*^9}, {3.699482536705633*^9, 
   3.699482559751892*^9}, {3.699482593801318*^9, 3.699482638102832*^9}, {
   3.6994826703041677`*^9, 3.6994827007275057`*^9}, {3.6994831426566076`*^9, 
   3.699483157056759*^9}, {3.699483317132812*^9, 3.6994833244469028`*^9}, {
   3.699483450040555*^9, 3.699483451078581*^9}, 3.699490518199256*^9, {
   3.699491368270188*^9, 3.6994913697702117`*^9}, {3.6994914995043926`*^9, 
   3.6994915210536356`*^9}, {3.6994915722999144`*^9, 
   3.6994915980852084`*^9}, {3.699491645666603*^9, 3.6994916797365522`*^9}, {
   3.6994917572819233`*^9, 3.699491758531949*^9}, {3.6994919441728015`*^9, 
   3.6994919986724243`*^9}, {3.6994922531217575`*^9, 3.699492306304959*^9}, {
   3.6994925952690063`*^9, 3.699492638467479*^9}, {3.699492862754057*^9, 
   3.6994928708351574`*^9}, {3.6994929604580975`*^9, 
   3.6994930101330886`*^9}, {3.69949340164092*^9, 3.699493544256486*^9}, {
   3.6994935871429296`*^9, 3.699493592712996*^9}, {3.6994939231696606`*^9, 
   3.699494042249013*^9}, {3.6994945270503263`*^9, 3.699494556104675*^9}, {
   3.699494588241181*^9, 3.699494593209244*^9}, {3.6994946434652824`*^9, 
   3.6994946522193766`*^9}, {3.6994948408745484`*^9, 
   3.6994949038337893`*^9}, {3.6994951406685824`*^9, 3.699495153872743*^9}, {
   3.6994954537520037`*^9, 3.6994955029572477`*^9}, {3.6994958059057007`*^9, 
   3.6994958317775173`*^9}, {3.6994960170016985`*^9, 
   3.6994960353349843`*^9}, {3.6994962233297153`*^9, 3.699496245028079*^9}, {
   3.6994964246063943`*^9, 3.6994964770430093`*^9}, {3.6994968232440195`*^9, 
   3.699496905382117*^9}, {3.6994971449302998`*^9, 3.6994971651315765`*^9}, {
   3.6994973905431676`*^9, 3.699497391514189*^9}, {3.699497582035396*^9, 
   3.699497582582401*^9}, {3.699497776840125*^9, 3.6994977909343667`*^9}, {
   3.6994979430312004`*^9, 3.6994979436732063`*^9}, {3.699498183174486*^9, 
   3.6994981957552013`*^9}, {3.6994983553368344`*^9, 3.69949835591884*^9}, {
   3.6994987256063256`*^9, 3.699498752425684*^9}, {3.6994991787143927`*^9, 
   3.699499221825858*^9}, {3.6994999478587418`*^9, 3.699499948726778*^9}, {
   3.6995001923607626`*^9, 3.699500203295373*^9}, {3.699500242110631*^9, 
   3.699500271017503*^9}, {3.6995006158425107`*^9, 3.6995006296814528`*^9}, {
   3.699500681365853*^9, 3.6995006818478565`*^9}, {3.69950086100342*^9, 
   3.6995008680978255`*^9}, 3.6995012491763716`*^9, {3.699501589256172*^9, 
   3.699501602639827*^9}, {3.6995016475984163`*^9, 3.6995016522984824`*^9}, {
   3.699501967189351*^9, 3.6995019904646273`*^9}, {3.699502035025631*^9, 
   3.6995020594489427`*^9}, {3.6995022813541455`*^9, 3.699502333257804*^9}, {
   3.699502596156233*^9, 3.699502607516391*^9}, {3.6995026664096174`*^9, 
   3.6995027060568852`*^9}, {3.699503097535492*^9, 3.6995031112401934`*^9}, {
   3.699503431947647*^9, 3.6995034320996513`*^9}, {3.69950373896317*^9, 
   3.699503739829195*^9}, {3.6995038103730955`*^9, 3.6995038175767107`*^9}, 
   3.6995043380495777`*^9, 3.699505102612139*^9, {3.699505573111244*^9, 
   3.69950557660979*^9}, {3.69950575877691*^9, 3.6995058081055946`*^9}, {
   3.69950594521286*^9, 3.699505945777878*^9}, {3.699506429545169*^9, 
   3.699506431055205*^9}, 3.699649045963321*^9, {3.69964910335049*^9, 
   3.6996491167326803`*^9}, {3.6996792077741995`*^9, 3.699679208626202*^9}, 
   3.699842411015895*^9, 3.699842703677684*^9, {3.699843205127737*^9, 
   3.699843232562149*^9}, {3.6998435051156797`*^9, 3.699843523541986*^9}, {
   3.699843684088401*^9, 3.699843698868675*^9}, {3.699844187755797*^9, 
   3.6998442089541783`*^9}, {3.6998446424740195`*^9, 
   3.6998446488221197`*^9}, {3.699844773912319*^9, 3.6998448043827996`*^9}, {
   3.699844959316873*^9, 3.6998449760851593`*^9}, {3.699845180598965*^9, 
   3.6998452009843035`*^9}, {3.6999222737274103`*^9, 
   3.6999223038399296`*^9}, {3.699922467930765*^9, 3.699922500455415*^9}, {
   3.699922753190627*^9, 3.699922781785144*^9}, {3.6999233062784843`*^9, 
   3.6999233434271135`*^9}, {3.699923534837812*^9, 3.6999235481240606`*^9}, {
   3.6999237729759274`*^9, 3.699923788686199*^9}, 3.6999242918265076`*^9, {
   3.6999252351799607`*^9, 3.6999252545572968`*^9}, {3.699925512234182*^9, 
   3.699925548239298*^9}, {3.6999256465498233`*^9, 3.699925671574255*^9}, {
   3.69992599997511*^9, 3.699926016775377*^9}, {3.699935807821692*^9, 
   3.699935823479484*^9}, {3.6999360827481728`*^9, 3.6999360955414104`*^9}, {
   3.6999362498244877`*^9, 3.69993626533486*^9}, {3.699936765517598*^9, 
   3.699936780776895*^9}, {3.6999369515037813`*^9, 3.699936964229017*^9}, {
   3.699937098230827*^9, 3.699937110232059*^9}, {3.6999372515848455`*^9, 
   3.699937268103258*^9}, {3.700099313474965*^9, 3.700099328772277*^9}, {
   3.700100267443804*^9, 3.700100276455996*^9}, {3.700100317326275*^9, 
   3.7001003196354055`*^9}, {3.7001010599973087`*^9, 
   3.7001010966885653`*^9}, {3.7001036127146263`*^9, 
   3.7001036132066345`*^9}, {3.7001040847875814`*^9, 
   3.7001041005924664`*^9}, {3.7001043220202913`*^9, 
   3.7001043358891306`*^9}, {3.7001045174596167`*^9, 3.700104530590444*^9}, {
   3.7001046443094063`*^9, 3.700104690836027*^9}, {3.7001049218838825`*^9, 
   3.70010492217589*^9}, {3.7001050425474787`*^9, 3.700105043035491*^9}, 
   3.700106057139503*^9, {3.7001072494316893`*^9, 3.7001072503437295`*^9}, {
   3.7001078165506377`*^9, 3.7001078281778975`*^9}, {3.7001085282649097`*^9, 
   3.7001085529734697`*^9}, 3.700108889007246*^9, {3.700110468239107*^9, 
   3.7001104926132455`*^9}, {3.7001118523648195`*^9, 
   3.7001118925282393`*^9}, {3.7001120819597635`*^9, 
   3.7001120950055504`*^9}, {3.7001126647754135`*^9, 3.700112671642424*^9}, {
   3.7001132798859243`*^9, 3.700113286909449*^9}, {3.700626750439461*^9, 
   3.7006267551107283`*^9}, 3.7010509998724513`*^9, 3.7010516046284647`*^9, {
   3.701052942588142*^9, 3.7010529469606485`*^9}, 3.7010531330616045`*^9, {
   3.701053241662981*^9, 3.7010532575075054`*^9}, {3.701053441461638*^9, 
   3.701053446241645*^9}, 3.701053580166561*^9, {3.701053820905078*^9, 
   3.7010538276050873`*^9}, {3.701054051057499*^9, 3.7010540514275*^9}, 
   3.701054132226843*^9, 3.7010543644368877`*^9, {3.7010545789984217`*^9, 
   3.701054581713426*^9}, 3.701055764830386*^9, {3.7010558497832084`*^9, 
   3.7010558551602187`*^9}, {3.7010561201388993`*^9, 3.701056124851406*^9}, {
   3.7010563132834682`*^9, 3.701056331847499*^9}, {3.701056654293824*^9, 
   3.7010566742458544`*^9}, {3.7010569333024144`*^9, 3.701056945439932*^9}, {
   3.7010571351644554`*^9, 3.701057148795988*^9}, 3.701057255031584*^9, 
   3.701057362240461*^9, 3.7010575260413337`*^9, {3.701057698965373*^9, 
   3.7010577136798954`*^9}, 3.701057821755186*^9, 3.7010579268475204`*^9, {
   3.701058125896383*^9, 3.701058131795396*^9}, 3.7010583338116226`*^9, 
   3.70105844396099*^9, {3.701058624585156*^9, 3.701058624697159*^9}, {
   3.7010587021839404`*^9, 3.701058713487973*^9}, {3.701058852143254*^9, 
   3.7010588526582546`*^9}, {3.7010589504250727`*^9, 3.701058958679096*^9}, 
   3.7010594868939004`*^9, {3.7010596789068346`*^9, 3.7010596793568354`*^9}, {
   3.7010597112229085`*^9, 3.701059711682909*^9}, {3.701059815969212*^9, 
   3.701059816571215*^9}, 3.7010599384718027`*^9, 3.7010600004141965`*^9, 
   3.7010601250846653`*^9, {3.7010602412857065`*^9, 3.7010602417557073`*^9}, {
   3.701060312860001*^9, 3.7010603133720036`*^9}, {3.70106040413034*^9, 
   3.7010604045623417`*^9}, 3.7010606289553137`*^9, {3.7010607960938873`*^9, 
   3.7010607968838887`*^9}, {3.701061070652645*^9, 3.7010610775526547`*^9}, 
   3.701061199405472*^9, {3.701061984472709*^9, 3.7010619849572115`*^9}, {
   3.7010621411585093`*^9, 3.70106214123851*^9}, {3.7010622308102827`*^9, 
   3.701062230900283*^9}, {3.7012937545030594`*^9, 3.7012937682010856`*^9}, {
   3.7012939833216286`*^9, 3.7012939863556447`*^9}, {3.701294080067952*^9, 
   3.7012940883039675`*^9}, {3.7012942257942657`*^9, 
   3.7012942336562786`*^9}, {3.701294761015444*^9, 3.701294767777501*^9}, 
   3.7012949272420344`*^9, {3.7012950209122014`*^9, 3.7012950251442084`*^9}, {
   3.701295198962722*^9, 3.7012952062247334`*^9}, {3.7012954680774717`*^9, 
   3.70129547422748*^9}, {3.701295611198247*^9, 3.701295617372259*^9}, 
   3.701295680476564*^9, {3.7012957111967306`*^9, 3.7012957113067303`*^9}, {
   3.7012958412371063`*^9, 3.701295869645155*^9}, {3.701295949417547*^9, 
   3.701295950157548*^9}, {3.701296010375716*^9, 3.701296011075718*^9}, {
   3.7012961390301743`*^9, 3.7012961439301915`*^9}, {3.7012962106404905`*^9, 
   3.701296210830491*^9}, {3.7012963863369775`*^9, 3.7012963987309976`*^9}, {
   3.7012966057216263`*^9, 3.7012966062936277`*^9}, 3.701301696090576*^9, 
   3.701301812956058*^9, {3.701301973453188*^9, 3.7013019916642227`*^9}, {
   3.70130208665958*^9, 3.7013021086846256`*^9}, 3.7013022318659782`*^9, {
   3.7013023570904083`*^9, 3.7013023572704086`*^9}, {3.701302462692833*^9, 
   3.7013024691748433`*^9}, 3.701302551697173*^9, {3.701302658589677*^9, 
   3.701302658769677*^9}, {3.7013027462999783`*^9, 3.701302746409978*^9}, 
   3.701302843952347*^9, {3.701302889672654*^9, 3.701302889872654*^9}, {
   3.7013074568892546`*^9, 3.7013074659092674`*^9}, {3.701307633114798*^9, 
   3.7013076407708173`*^9}, 3.7013077619358253`*^9, {3.7013083925931187`*^9, 
   3.701308396045124*^9}, 3.7013084962400904`*^9, {3.7013085643249397`*^9, 
   3.7013085644649396`*^9}, 3.701308722716036*^9, {3.701308804213459*^9, 
   3.7013088044954605`*^9}, 3.701308919477749*^9, 3.7013090280972652`*^9, {
   3.7013091565565805`*^9, 3.7013091601036167`*^9}, {3.701309292410013*^9, 
   3.7013092927400136`*^9}, {3.701309401209594*^9, 3.7013094042470984`*^9}, {
   3.701309451682272*^9, 3.7013094600892854`*^9}, 3.701309602417472*^9, {
   3.7013096430293703`*^9, 3.701309643211372*^9}, {3.701309751028203*^9, 
   3.701309751410205*^9}, {3.701399608808082*^9, 3.7013996147321076`*^9}, 
   3.701399835752613*^9, {3.701400321967676*^9, 3.701400327827685*^9}, 
   3.701403314548468*^9, {3.7014048378878365`*^9, 3.7014048462078485`*^9}, {
   3.701481772478508*^9, 3.701481778347519*^9}, {3.701481861772686*^9, 
   3.701481867997696*^9}, {3.701482006977427*^9, 3.7014820096974306`*^9}, {
   3.7014820690660453`*^9, 3.7014820774010572`*^9}, {3.7016561720124564`*^9, 
   3.701656202107001*^9}, {3.7016562634101467`*^9, 3.701656263800147*^9}, {
   3.7016565305452304`*^9, 3.701656537388744*^9}, {3.701656570796348*^9, 
   3.7016565709233494`*^9}, {3.7016566858718324`*^9, 
   3.7016566901518383`*^9}, {3.701656792589652*^9, 3.7016568011071644`*^9}, {
   3.701656983258112*^9, 3.701656990733122*^9}, {3.701657121773961*^9, 
   3.7016571253959684`*^9}, {3.7016572876539097`*^9, 
   3.7016572941269407`*^9}, {3.7016573671317177`*^9, 3.701657370421728*^9}, {
   3.7017451402413387`*^9, 3.7017451417813406`*^9}, {3.7017455745201826`*^9, 
   3.7017455750821843`*^9}, {3.701746868636608*^9, 3.70174686986661*^9}, {
   3.7017476039797554`*^9, 3.701747604129756*^9}, 3.7017478278665166`*^9, {
   3.7017479590720043`*^9, 3.7017479598220053`*^9}, 3.701749042136195*^9, {
   3.7017492030524387`*^9, 3.7017492083274593`*^9}, {3.7017492852523785`*^9, 
   3.7017492919098997`*^9}, {3.7017495178750796`*^9, 3.70174952080009*^9}, {
   3.7017497117181916`*^9, 3.7017497173692102`*^9}, {3.7024350334387093`*^9, 
   3.7024350451872864`*^9}, 3.702435539151341*^9, {3.702435735618021*^9, 
   3.702435753394064*^9}, {3.702435846010313*^9, 3.702435852063826*^9}, {
   3.7024367743903255`*^9, 3.7024367745403256`*^9}, {3.702436868301688*^9, 
   3.7024368683916883`*^9}, {3.7024377997266936`*^9, 
   3.7024378072282095`*^9}, {3.7024381814921293`*^9, 
   3.7024381929786825`*^9}, {3.702438453437608*^9, 3.7024384569376345`*^9}, {
   3.702438646372484*^9, 3.7024386496835003`*^9}, {3.7024388576714716`*^9, 
   3.7024388651796494`*^9}, {3.702438979734237*^9, 3.702438984207256*^9}, {
   3.702439093135835*^9, 3.7024391011773634`*^9}, {3.7024392042162333`*^9, 
   3.7024392101462636`*^9}, {3.702439700716745*^9, 3.7024397090927734`*^9}, {
   3.702439917307397*^9, 3.7024399322636323`*^9}, {3.7024400671383915`*^9, 
   3.7024400735024176`*^9}, {3.7024401901349936`*^9, 3.702440203531027*^9}, {
   3.7030218894629927`*^9, 3.703021896395013*^9}, {3.7030222957412386`*^9, 
   3.7030223012072587`*^9}, {3.703022517371039*^9, 3.7030225249430723`*^9}, {
   3.7030226628876877`*^9, 3.703022668299713*^9}, {3.7030230477316837`*^9, 
   3.7030230668079925`*^9}, {3.7030231627377543`*^9, 
   3.7030231698397846`*^9}, {3.7030232606023865`*^9, 
   3.7030232665944123`*^9}, {3.7030234233788757`*^9, 
   3.7030234358149357`*^9}, {3.703023665040906*^9, 3.7030236722309427`*^9}, {
   3.703023863207616*^9, 3.7030238879816523`*^9}, {3.7031102115482025`*^9, 
   3.703110230487731*^9}, {3.703121880827084*^9, 3.703121886407119*^9}, {
   3.703123360263007*^9, 3.703123368718042*^9}, {3.7031236404067416`*^9, 
   3.7031236473517756`*^9}, {3.703123901051488*^9, 3.70312392712458*^9}, {
   3.7031240468721676`*^9, 3.703124050223184*^9}, 3.703124472939066*^9, {
   3.7031253336258125`*^9, 3.703125338896333*^9}, {3.703125832353129*^9, 
   3.7031258378951583`*^9}, {3.7031261691736393`*^9, 3.703126174273647*^9}, {
   3.7031262998054457`*^9, 3.70312630270446*^9}, {3.7031264246442204`*^9, 
   3.7031264297522483`*^9}, {3.703126949658742*^9, 3.7031269590237865`*^9}, {
   3.704067596940584*^9, 3.7040675970805845`*^9}, {3.704768286219001*^9, 
   3.7047682982870445`*^9}, {3.704768444823368*^9, 3.7047684617094193`*^9}, {
   3.7047698282303247`*^9, 3.7047698378073387`*^9}, {3.704771335702944*^9, 
   3.7047713448109818`*^9}, {3.7047717173648643`*^9, 
   3.7047717237353735`*^9}, {3.7047720591238794`*^9, 
   3.7047720597098866`*^9}, {3.7047738423123817`*^9, 
   3.7047738524969573`*^9}, {3.7047740296710815`*^9, 3.704774040356643*^9}, {
   3.7047742156247077`*^9, 3.7047742318442388`*^9}, {3.70494226954067*^9, 
   3.7049422697606697`*^9}, {3.705119320940513*^9, 3.7051193212205133`*^9}, {
   3.7113283946077538`*^9, 3.711328395457755*^9}, {3.7113291157169504`*^9, 
   3.7113291164889526`*^9}, {3.711329148609006*^9, 3.711329154119014*^9}, {
   3.711329430889984*^9, 3.7113294372239947`*^9}, {3.7113299977892017`*^9, 
   3.711330004463228*^9}, {3.7113315093397493`*^9, 3.7113315093997493`*^9}, {
   3.711423406750684*^9, 3.711423406860684*^9}, {3.7122051532567387`*^9, 
   3.712205153658741*^9}, {3.7131454692320733`*^9, 3.7131454838581014`*^9}, {
   3.7136515278468356`*^9, 3.713651529028844*^9}, {3.713835507363612*^9, 
   3.713835520126954*^9}, {3.7138358969367943`*^9, 3.7138358972418118`*^9}, 
   3.713836043416851*^9, 3.7139226695961866`*^9, 3.7139299512109547`*^9, {
   3.7146913142622957`*^9, 3.714691317295371*^9}, {3.714692040271596*^9, 
   3.7146920407735987`*^9}, {3.721450182252941*^9, 3.721450182824943*^9}, {
   3.740548557366831*^9, 3.7405485591348515`*^9}, {3.740548621890007*^9, 
   3.7405486643201075`*^9}, {3.7405487174322166`*^9, 
   3.7405487232912273`*^9}, {3.7405488441145873`*^9, 
   3.7405488902247214`*^9}, {3.740549724303006*^9, 3.7405497245830064`*^9}, {
   3.7405521158652515`*^9, 3.74055213153128*^9}, {3.7405541778788958`*^9, 
   3.740554179674903*^9}, {3.740554231830031*^9, 3.7405542499930973`*^9}, {
   3.7406133959438906`*^9, 3.74061340424197*^9}, {3.7406134406380324`*^9, 
   3.7406134835681486`*^9}, {3.7406135466163645`*^9, 3.7406135500763693`*^9}, 
   3.7406135816314645`*^9, {3.740613824989372*^9, 3.7406138425194197`*^9}, {
   3.7406138983515706`*^9, 3.740613901071574*^9}, {3.740614023178045*^9, 
   3.740614027400051*^9}, {3.740614619348184*^9, 3.7406146197581844`*^9}, {
   3.740614650633256*^9, 3.7406146531052637`*^9}, {3.7406151777164245`*^9, 
   3.7406152265885563`*^9}, {3.740615268710661*^9, 3.740615270130663*^9}, {
   3.740615310821783*^9, 3.740615311771785*^9}, {3.740615391303715*^9, 
   3.740615396265755*^9}, {3.7406308502822165`*^9, 3.74063088233433*^9}, {
   3.7406309225024133`*^9, 3.740630974112542*^9}, {3.7406310468107424`*^9, 
   3.7406310523367634`*^9}, 3.740699333573804*^9, {3.7407011098610106`*^9, 
   3.740701110188611*^9}, {3.740701387369898*^9, 3.7407013922059064`*^9}, {
   3.7407028976241503`*^9, 3.7407029215701923`*^9}, {3.740703024857974*^9, 
   3.7407030310355844`*^9}, {3.7407056431720967`*^9, 
   3.7407056610809283`*^9}, {3.740705694402587*^9, 3.740705694605387*^9}, {
   3.740705727568245*^9, 3.740705752762289*^9}, {3.7407065539384995`*^9, 
   3.7407065689301257`*^9}, {3.740708861756153*^9, 3.7407088620681534`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"6c255fb8-e875-4d6c-a224-26c2a0c3bec6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "Stationary", " ", "Distribution", " ", "of", " ", "Spine", " ", "Volume"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"param", "=", "WT"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dV", "=", "0.005"}], 
  ";"}], "\[IndentingNewLine]", "\"\<Volatility \[Sigma] (KO, WT)\>\"", "\
\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "KO", "]"}], "[", "V", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"\[Sigma]", "[", "WT", "]"}], "[", "V", "]"}], 
  "]"}], "\[IndentingNewLine]", "\"\<Drift \[Mu] (KO, WT)\>\"", "\
\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"\[Mu]", "[", "KO", "]"}], "[", "V", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"\[Mu]", "[", "WT", "]"}], "[", "V", "]"}], 
  "]"}], "\[IndentingNewLine]", "\"\<Probability density of stationary volume \
distribution\>\"", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"stationaryDistribution", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"param", ",", "V"}], "]"}], ",", " ", 
     RowBox[{"{", " ", 
      RowBox[{"V", ",", "0.005", ",", "0.5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "ProbDensOrdinate"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"P", "[", 
       RowBox[{"KO", ",", "V"}], "]"}], ",", 
      RowBox[{"P", "[", 
       RowBox[{"WT", ",", "V"}], "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", " ", 
     RowBox[{"V", ",", "0.005", ",", "0.5"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<KO\>\"", ",", "\"\<WT\>\""}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"stationaryDistribution", ",", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.698902187800824*^9, 3.698902189485921*^9}, {
   3.698981135633431*^9, 3.6989811369874363`*^9}, {3.699130954433125*^9, 
   3.699130954555126*^9}, {3.6994773457351966`*^9, 3.6994773467712173`*^9}, {
   3.6994791769529095`*^9, 3.699479181976971*^9}, {3.6994792166857758`*^9, 
   3.6994792725907927`*^9}, {3.6994876405582795`*^9, 
   3.6994876436423254`*^9}, {3.6994986978294263`*^9, 3.699498699442436*^9}, {
   3.699924931496003*^9, 3.6999249579177103`*^9}, 3.7017479464149847`*^9, {
   3.740549783394206*^9, 3.7405497872882223`*^9}, {3.7405499552987857`*^9, 
   3.7405499671518435`*^9}, {3.7405501230042334`*^9, 
   3.7405501995323963`*^9}, {3.74055111623307*^9, 3.7405511768463*^9}, {
   3.7406139519537487`*^9, 3.740613969089842*^9}, {3.740698955304385*^9, 
   3.740699040386526*^9}, {3.7406992555736437`*^9, 3.740699262165654*^9}, {
   3.7406995581813617`*^9, 3.740699649459533*^9}, {3.7407000808416886`*^9, 
   3.740700143500801*^9}, {3.7407096546431456`*^9, 3.740709671085575*^9}, {
   3.740710303729086*^9, 3.740710305055088*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"2163fde9-a6d5-4789-afdf-273ea69ba2c6"],

Cell[BoxData["\<\"Volatility \[Sigma] (KO, WT)\"\>"], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.7409825159240932`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"4952214c-8ae0-4da8-9350-a82991a830a3"],

Cell[BoxData[
 RowBox[{"0.0023560797949135777`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.19643426381362292`", " ", 
   SuperscriptBox["V", 
    RowBox[{"2", "/", "3"}]]}]}]], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.740982515934269*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"5c61c9c6-6a55-4bc2-99d4-6b1102f9d06b"],

Cell[BoxData[
 RowBox[{"0.005758677625983244`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.1397242999624618`", " ", 
   SuperscriptBox["V", 
    RowBox[{"2", "/", "3"}]]}]}]], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.740982515941537*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"80a300cc-9353-421f-93b5-95605b36fdb0"],

Cell[BoxData["\<\"Drift \[Mu] (KO, WT)\"\>"], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.740982515949378*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"246d1c91-16a3-41a3-a06c-d756fb9cc373"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.06`"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "0.24328807982293602`"}], "+", 
    SuperscriptBox["V", 
     RowBox[{"2", "/", "3"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.740982515956936*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"baa44a71-bd93-487b-b4ae-e59e9396cc2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.06`"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "0.24328807982293602`"}], "+", 
    SuperscriptBox["V", 
     RowBox[{"2", "/", "3"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.740982515964171*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"89ba804c-41a8-4cf0-bc2d-ba4816cdc545"],

Cell[BoxData["\<\"Probability density of stationary volume \
distribution\"\>"], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.740982515971739*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"5141e67b-8cce-4956-aa87-faa653463050"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0, 0]], 
          LineBox[CompressedData["
1:eJwV1Xk41NsfB3DRclOWscx8v+ImRaTsu/iclBKStZSsl7KUpdCVXSKULUv2
fZmxNNYrWmY0WUpkT5YRhVQqFFl/8/vjPOd5/XGe55z353PO2efgYerEzsbG
xmSN/89PeSbXJ295Q+l6XaNx3S8Y169LFRDygb1X+gKaVX/D1ohIed3HPvAF
1TYlNf4G/TVpp+IlX1iIsNbVoi/BwIx3h7O3H6wsRzu/7/4Dc/TtGd+uBUGq
5P0M8so68GoIZvrLhYORY7yBvxgHyj+/McMfEg719XpZWx05kKLPtHJ5Vzj0
q77odS3iQOeoj7tG3O/AZPsStB7cijIlbDi0KyKANBJY/+DQNiTFX+LKdigK
LJ5zymkc3IF0vqqp39kfC7/DxbnTFjmRRejgzS6/WHgVsmIvobQLORN96/G3
sfBpZdze7sYudB/VKFYGxIHoN0xz8McudPUVMfWLazzIScKnpundqP7vhAQB
RgLEfhld6GdwI3AZp6p/T4Cm/MC8sQ1u1FYj+9ZGKBGytdVzo9V40LBeJzfZ
MxHMn1cLv6bwILYbu+5piTyA2YOBMdd1eZF+652Iy75JkHbq9HK+MAH1EvqL
YvKSYOrf5stVKgR06dKBl9SOJHDcRm6IMyYgj5/NHKtiyTDW2zLRdJuAkvaw
hcZ1JYONXciT7mkCGvO45d8gmQqXNo9HLhbzoRuYhyfncBqcz0eublsEkJ1+
XbYZRzqILpJuygoIIMOA1Y5M6XTo3znB9VpCAB0Yj5SSDUiHQs1InSgDATRQ
kjthJpIBn0YD2g88EEBqqj3mWbaZ8NY3RmheSBAdcMFuT0VmgoyKl9ZRaUFE
yLCpkqVmwlcF1Q5bTUE0uzHL1cyWBcpJEXWKVoIoo4WjdSovC2pzCOF8aYJo
w0JZXe5jNqgJG9x+zUVEs5H+V/x258Dk5bltT/cQ0cBjenKzUg7c1VdRj5Yi
okciRvPmd3IgcPegQcMJIqJer+k/yp8LAkNLDlf8iMhBoyPWvjYXuEM/zymO
EJGl2XfxiLZcWFwXmpqfJiKjq3xPKSO5QBld+Ct+gYg0si2/LGzNg8GCO95O
nCTEz/7pVIRFHjw9nm0VqkJCjPZ1trLfecD4J/Ji3l0Skjir4+XKmQ8vLit3
iyeS0N2+iA9Sf+cDxy8FzXsZJGTI5Gku1c0H+lhz+GYFCfUt7rtdnJQPdwV0
ZcO7SWhy78lt+QoFcNlGaeggP4ZOFEX72J8sAExV8PGoEIaKD3V9Er1YAA6c
+ss3xTDkqmzZkhNaANVKhjIX5TE0r+8amfW2AFKf55UOncEQu2/szjT3QhDi
lReZCsWQ42qPn2UYy9aDXQuRGGoJIc2SUgoBEXTRzH0MRcfkvkp5Wgj2Zej7
nTQM8eVVxyTtLgLvlLWEh48w5C2xtGomWgRDTnQYr8XQQJnmVX6lIlDf49jD
04ih9HqGYaJVETB3zqgeZGBoX8cAVzylCDyT/P9oDGIozGRP0NlnRWCn+C/j
5TCGPg7YznH3FMF89dsk9XEMlX6Y6bz/pwgk5B73jsxgSG5pJS5Grxh+9s0W
C/7BUGIAsBlcKoZDXXy3vq5haHFLuCenZzF4MPrdKthw1LCbyyQqtRgS9e4q
z+3AERLbyxc5VQxsB4/t9xDEUdi27o351WL4LkUIHcNwxJgJ+2JDKAGq+2dH
ZWEcnX40xVA5WgIuDsKu6WI4upf4sCrfpATuxTWOl4rjqNNHP5v7SgkYx05H
5kjiyPRo5c2phBJYGw/kPSmDo6S9do6mJSXwY6BJ97ccjgbY+UyePSmBzmh5
szhFHF1s9zmUMl0Cu4PdMwPUcPTPOa1RXa1ScCE9dNI7hqNi9e/tVaalUFyu
M3z8OI5mhPPqRZxLoVS71kNKF0dXJ7fG/0oshbqaqqQaPRxVttQH2JeWQrk2
2dtSH0c/yM4ub56WwtJPbb4ZAxx5e3boFM2Uwt117v1tRjiqNwuSJWyUwrtX
Kh8xYxwtq8gJB/KToTNpcMPcBEcaQhN/fZYkQ/lJz7QAUxwFrj/4Za5NBp/u
s+/jzHBEG9edoJmRwV8ieTrWHEfsjKXOwy5kqFOUnfazwNGJEnLTwyAyVHwY
2TA+h6OIaKvSrUlkoPAdMRc4j6O2a1zJnmQy2BcE7WawzGnyPHTkGRnUr7Gd
sbPEkaGSl7teHxnSTldpfGY5jrTfqvYzGbqIdis2F3DUs9J3SnSTDDLPyqh0
lgXGIpTuCVDAVpMjjHARR+foavuWpSiAFRUlGrH8sHCWyxEo0KSSv92P5feR
mStd5hRIsXq3JYFlYTejaU1XCjxpXCpJYdnGiK2vJJgCoSdChKNZzpWvpvEn
U6ABNYe5sTwh4FgRTKHApvXYugbLB5YF0788p0C+j/+jZdZ+Lg+3Rpzvp8Cb
ucknhSyTn/ndeDFLARlDt1PA8tc8aTtZtjKYuO3t1cY6n8ydUcMMwTIYNVK0
Rix7Osep75Aug3Gt8sMlrHyqDY5J3EBl8F9X7ZZ1Vp6LMgt8TIsy4Lu7sH6M
ZRW+ok19tzI4u2Ncx5eVf+O7v4bEUspgbaNeuoJVr7WmxpexZWWgLllCoLLq
qZ1ztXqFVgYfKo0Z+ax6v3B6G9PzpQxeG44QLM/iaPvpsH+1t5RDBsHkmxCr
X/QOKzlRiOXg0l5I7DTEUcd8qnbYsXIQ8BPo2cbqN9rplwohFuVgZzvtWsjq
x9rceYkgl3I4f+IIQ/kUjjKMzvDcSigHXXN5EfkTOHKlsI97fSiH3QM+4ve1
WHlvkevz+FUOET+PBDM0WffJ0rrt2s4KaJTZa/ddHUfq2xuoLvIVYD0Yg4mq
4Ogvh2uh9qEVoDVowv7jCOt8Dek+tskVcCv1tnKLNKv/edpcrMkVMOqkVxkv
haPBp2KmF7orwDD4+Bt21v0txt+JmeyrBH+zKR2bPTg63q3DQPRKiJ+Xrt62
nZWnpGeDdn8lYC8khw5x4OhQcFb50c+VwO3FTtFlvS98R5aT1AiPgGrElX1p
BUPjdyuc5OwfgVXhLiG+OQyB6D2OeDYqRP/QMa3oxdDo4O/C4FwqpLJfVpJ5
iKGTCidGzcuoEJue5zn0AEPUewmCh+qp8HjvE0f/OAyFHzsc0feaCsD5+U1B
BIYOl9lfkVqigkpeFFeUN4YCgjqkes9UAYcmXbDBCEPC4vmVEqtV0N3dV6m6
TkKXrp9peGNRA7aNHSOvT5LQWpi0taddDVyVUqoeRiSU+WAnO79bDYwUVa1O
aZDQSO1LA8uQGti+p2bfDxkSslrSYk5QaoBjfUaxk0hCFwNkti9v1gCEGC8y
PrH+ywgeczFKLev/dzBZDCEis/Tu774bdbBhamPxtlIQ+asxiPZ+DSAqXTqk
QBRAZYkOr99LNUGgaU6huCUf2v2Ph0dy+VMYD6lqvM7gRTfG+zIsCDR4cyM5
m5DOjRy/tZ6UvEKHD36EC835u5C78nWXPcXNcGTNuIiduBMFWM2bDmy+ANFX
f66Uxm1HJ/WiOrXNXgIWQm/gNdmKpDwH6a1xLRAzkdbY5MaOeH1X/bHpVjh6
88Lf9+LZEM9/AxVRB9shx7V93Zd9A/gGIoubw15B1Vp2IX15BXqazsqTB19D
wKyzlfuZZaCMdCpSBd/AEyM5/WDe3xAxvH89yL0Tzi31H4ueWIBbgnLa7tQu
CFzRdv7CPQ+CMeS723zfwkl3p+smXj/AY6WoX3VfNxzzl0hDTd/g3I4gmxVa
N7ibhIlHCn4B4KC/EnXvAZn629r1ITMQ4cDD9jfWC8ORUJ2kMQUXbNW9yup7
4QVH6bmXxh9BxqDzZaZDH9RN3dP08pqAuD7tc39z9ENQSYNKweg4GNEbH/nm
9kPUdFj34tcx4MnK+6pgMADXLqYomUiPgDXR0Sl4dgDiJj29lQeHoCIogS6b
Ogj2lhukkfuDEBWefsFT7R24xKwIl2f3w4tvlY2RA+/gp196wP2PvbCpK7PJ
HjYEtfZNf/6T64FWzahgbrH3IKvcdGb12VtIED07Gdj1HgI4bEV1ijrhsbMo
L8NvGA7Ao9+7hDvA3ejNv+nYCPwMPS78cqEdxPd/YvQxRqBvzvjrje5WcE5+
Z5jjNAoZ2orpvGwtsNNtMAtxjAGDwDdDt2ZAueyxHt3KMUizWxvxftYMwwkR
OsNnmLC4/9npdis6nBAw6S8wZkKh9U+BUQs6lKfscb5qxoSWMjeRhbN0CMqg
3l+3ZIKudOCE+Ak6iBW9f7fXkQkbLaL7iw/TwaVBxsPxFhPIxfJU3g0aLI0N
ZHwrZoL4LeusyHwa2NnnydSTmTB+a8PgQyYN2ibd6EHlTKCqfhPSSqVB+gzb
NE81E9z7ZYmrMTTQnj+koPCUCXVmL1zifWhwZ1twm28vE94sajTvPU2DucjT
VjDAhH5rbq6M4zQ4xykwt2OICdBm6Ipp00CSh8yfNsYEhZgcS1yRBh1Yr03T
ZyZUkBlfFUVooJyR9fP2VyZ46gvWPCfRIFvEOdzwOxPu12y9c4aPBp5i6+TR
RSaMrdvpeeygwVBh69HiJdZ6u71qHOw00DmY2OW+woRTImCn8Oc5UMiXHFTX
mXDtBtHWYe458B8++Gtzkwk8M5hbyuRz+B9E53JX
           "]]}, 
         Annotation[#, 
          "Charting`Private`Tag$17880#1"]& ]}}, {}, {}}, {{{{}, {}, 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwVlHk41N0bxq0tkl22mS9RvFIoCZHnJCSvrewlWygUspUly8SMLRnZxzD2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           "]]}, Annotation[#, "Charting`Private`Tag$24104#1"]& ], 
        TagBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwV1Xk41NsfB3DRclOWscx8v+ImRaTsu/iclBKStZSsl7KUpdCVXSKULUv2
fZmxNNYrWmY0WUpkT5YRhVQqFFl/8/vjPOd5/XGe55z353PO2efgYerEzsbG
xmSN/89PeSbXJ295Q+l6XaNx3S8Y169LFRDygb1X+gKaVX/D1ohIed3HPvAF
1TYlNf4G/TVpp+IlX1iIsNbVoi/BwIx3h7O3H6wsRzu/7/4Dc/TtGd+uBUGq
5P0M8so68GoIZvrLhYORY7yBvxgHyj+/McMfEg719XpZWx05kKLPtHJ5Vzj0
q77odS3iQOeoj7tG3O/AZPsStB7cijIlbDi0KyKANBJY/+DQNiTFX+LKdigK
LJ5zymkc3IF0vqqp39kfC7/DxbnTFjmRRejgzS6/WHgVsmIvobQLORN96/G3
sfBpZdze7sYudB/VKFYGxIHoN0xz8McudPUVMfWLazzIScKnpundqP7vhAQB
RgLEfhld6GdwI3AZp6p/T4Cm/MC8sQ1u1FYj+9ZGKBGytdVzo9V40LBeJzfZ
MxHMn1cLv6bwILYbu+5piTyA2YOBMdd1eZF+652Iy75JkHbq9HK+MAH1EvqL
YvKSYOrf5stVKgR06dKBl9SOJHDcRm6IMyYgj5/NHKtiyTDW2zLRdJuAkvaw
hcZ1JYONXciT7mkCGvO45d8gmQqXNo9HLhbzoRuYhyfncBqcz0eublsEkJ1+
XbYZRzqILpJuygoIIMOA1Y5M6XTo3znB9VpCAB0Yj5SSDUiHQs1InSgDATRQ
kjthJpIBn0YD2g88EEBqqj3mWbaZ8NY3RmheSBAdcMFuT0VmgoyKl9ZRaUFE
yLCpkqVmwlcF1Q5bTUE0uzHL1cyWBcpJEXWKVoIoo4WjdSovC2pzCOF8aYJo
w0JZXe5jNqgJG9x+zUVEs5H+V/x258Dk5bltT/cQ0cBjenKzUg7c1VdRj5Yi
okciRvPmd3IgcPegQcMJIqJer+k/yp8LAkNLDlf8iMhBoyPWvjYXuEM/zymO
EJGl2XfxiLZcWFwXmpqfJiKjq3xPKSO5QBld+Ct+gYg0si2/LGzNg8GCO95O
nCTEz/7pVIRFHjw9nm0VqkJCjPZ1trLfecD4J/Ji3l0Skjir4+XKmQ8vLit3
iyeS0N2+iA9Sf+cDxy8FzXsZJGTI5Gku1c0H+lhz+GYFCfUt7rtdnJQPdwV0
ZcO7SWhy78lt+QoFcNlGaeggP4ZOFEX72J8sAExV8PGoEIaKD3V9Er1YAA6c
+ss3xTDkqmzZkhNaANVKhjIX5TE0r+8amfW2AFKf55UOncEQu2/szjT3QhDi
lReZCsWQ42qPn2UYy9aDXQuRGGoJIc2SUgoBEXTRzH0MRcfkvkp5Wgj2Zej7
nTQM8eVVxyTtLgLvlLWEh48w5C2xtGomWgRDTnQYr8XQQJnmVX6lIlDf49jD
04ih9HqGYaJVETB3zqgeZGBoX8cAVzylCDyT/P9oDGIozGRP0NlnRWCn+C/j
5TCGPg7YznH3FMF89dsk9XEMlX6Y6bz/pwgk5B73jsxgSG5pJS5Grxh+9s0W
C/7BUGIAsBlcKoZDXXy3vq5haHFLuCenZzF4MPrdKthw1LCbyyQqtRgS9e4q
z+3AERLbyxc5VQxsB4/t9xDEUdi27o351WL4LkUIHcNwxJgJ+2JDKAGq+2dH
ZWEcnX40xVA5WgIuDsKu6WI4upf4sCrfpATuxTWOl4rjqNNHP5v7SgkYx05H
5kjiyPRo5c2phBJYGw/kPSmDo6S9do6mJSXwY6BJ97ccjgbY+UyePSmBzmh5
szhFHF1s9zmUMl0Cu4PdMwPUcPTPOa1RXa1ScCE9dNI7hqNi9e/tVaalUFyu
M3z8OI5mhPPqRZxLoVS71kNKF0dXJ7fG/0oshbqaqqQaPRxVttQH2JeWQrk2
2dtSH0c/yM4ub56WwtJPbb4ZAxx5e3boFM2Uwt117v1tRjiqNwuSJWyUwrtX
Kh8xYxwtq8gJB/KToTNpcMPcBEcaQhN/fZYkQ/lJz7QAUxwFrj/4Za5NBp/u
s+/jzHBEG9edoJmRwV8ieTrWHEfsjKXOwy5kqFOUnfazwNGJEnLTwyAyVHwY
2TA+h6OIaKvSrUlkoPAdMRc4j6O2a1zJnmQy2BcE7WawzGnyPHTkGRnUr7Gd
sbPEkaGSl7teHxnSTldpfGY5jrTfqvYzGbqIdis2F3DUs9J3SnSTDDLPyqh0
lgXGIpTuCVDAVpMjjHARR+foavuWpSiAFRUlGrH8sHCWyxEo0KSSv92P5feR
mStd5hRIsXq3JYFlYTejaU1XCjxpXCpJYdnGiK2vJJgCoSdChKNZzpWvpvEn
U6ABNYe5sTwh4FgRTKHApvXYugbLB5YF0788p0C+j/+jZdZ+Lg+3Rpzvp8Cb
ucknhSyTn/ndeDFLARlDt1PA8tc8aTtZtjKYuO3t1cY6n8ydUcMMwTIYNVK0
Rix7Osep75Aug3Gt8sMlrHyqDY5J3EBl8F9X7ZZ1Vp6LMgt8TIsy4Lu7sH6M
ZRW+ok19tzI4u2Ncx5eVf+O7v4bEUspgbaNeuoJVr7WmxpexZWWgLllCoLLq
qZ1ztXqFVgYfKo0Z+ax6v3B6G9PzpQxeG44QLM/iaPvpsH+1t5RDBsHkmxCr
X/QOKzlRiOXg0l5I7DTEUcd8qnbYsXIQ8BPo2cbqN9rplwohFuVgZzvtWsjq
x9rceYkgl3I4f+IIQ/kUjjKMzvDcSigHXXN5EfkTOHKlsI97fSiH3QM+4ve1
WHlvkevz+FUOET+PBDM0WffJ0rrt2s4KaJTZa/ddHUfq2xuoLvIVYD0Yg4mq
4Ogvh2uh9qEVoDVowv7jCOt8Dek+tskVcCv1tnKLNKv/edpcrMkVMOqkVxkv
haPBp2KmF7orwDD4+Bt21v0txt+JmeyrBH+zKR2bPTg63q3DQPRKiJ+Xrt62
nZWnpGeDdn8lYC8khw5x4OhQcFb50c+VwO3FTtFlvS98R5aT1AiPgGrElX1p
BUPjdyuc5OwfgVXhLiG+OQyB6D2OeDYqRP/QMa3oxdDo4O/C4FwqpLJfVpJ5
iKGTCidGzcuoEJue5zn0AEPUewmCh+qp8HjvE0f/OAyFHzsc0feaCsD5+U1B
BIYOl9lfkVqigkpeFFeUN4YCgjqkes9UAYcmXbDBCEPC4vmVEqtV0N3dV6m6
TkKXrp9peGNRA7aNHSOvT5LQWpi0taddDVyVUqoeRiSU+WAnO79bDYwUVa1O
aZDQSO1LA8uQGti+p2bfDxkSslrSYk5QaoBjfUaxk0hCFwNkti9v1gCEGC8y
PrH+ywgeczFKLev/dzBZDCEis/Tu774bdbBhamPxtlIQ+asxiPZ+DSAqXTqk
QBRAZYkOr99LNUGgaU6huCUf2v2Ph0dy+VMYD6lqvM7gRTfG+zIsCDR4cyM5
m5DOjRy/tZ6UvEKHD36EC835u5C78nWXPcXNcGTNuIiduBMFWM2bDmy+ANFX
f66Uxm1HJ/WiOrXNXgIWQm/gNdmKpDwH6a1xLRAzkdbY5MaOeH1X/bHpVjh6
88Lf9+LZEM9/AxVRB9shx7V93Zd9A/gGIoubw15B1Vp2IX15BXqazsqTB19D
wKyzlfuZZaCMdCpSBd/AEyM5/WDe3xAxvH89yL0Tzi31H4ueWIBbgnLa7tQu
CFzRdv7CPQ+CMeS723zfwkl3p+smXj/AY6WoX3VfNxzzl0hDTd/g3I4gmxVa
N7ibhIlHCn4B4KC/EnXvAZn629r1ITMQ4cDD9jfWC8ORUJ2kMQUXbNW9yup7
4QVH6bmXxh9BxqDzZaZDH9RN3dP08pqAuD7tc39z9ENQSYNKweg4GNEbH/nm
9kPUdFj34tcx4MnK+6pgMADXLqYomUiPgDXR0Sl4dgDiJj29lQeHoCIogS6b
Ogj2lhukkfuDEBWefsFT7R24xKwIl2f3w4tvlY2RA+/gp196wP2PvbCpK7PJ
HjYEtfZNf/6T64FWzahgbrH3IKvcdGb12VtIED07Gdj1HgI4bEV1ijrhsbMo
L8NvGA7Ao9+7hDvA3ejNv+nYCPwMPS78cqEdxPd/YvQxRqBvzvjrje5WcE5+
Z5jjNAoZ2orpvGwtsNNtMAtxjAGDwDdDt2ZAueyxHt3KMUizWxvxftYMwwkR
OsNnmLC4/9npdis6nBAw6S8wZkKh9U+BUQs6lKfscb5qxoSWMjeRhbN0CMqg
3l+3ZIKudOCE+Ak6iBW9f7fXkQkbLaL7iw/TwaVBxsPxFhPIxfJU3g0aLI0N
ZHwrZoL4LeusyHwa2NnnydSTmTB+a8PgQyYN2ibd6EHlTKCqfhPSSqVB+gzb
NE81E9z7ZYmrMTTQnj+koPCUCXVmL1zifWhwZ1twm28vE94sajTvPU2DucjT
VjDAhH5rbq6M4zQ4xykwt2OICdBm6Ipp00CSh8yfNsYEhZgcS1yRBh1Yr03T
ZyZUkBlfFUVooJyR9fP2VyZ46gvWPCfRIFvEOdzwOxPu12y9c4aPBp5i6+TR
RSaMrdvpeeygwVBh69HiJdZ6u71qHOw00DmY2OW+woRTImCn8Oc5UMiXHFTX
mXDtBtHWYe458B8++Gtzkwk8M5hbyuRz+B9E53JX
           "]]}, 
         Annotation[#, "Charting`Private`Tag$24104#2"]& ]}}, {}, {}}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 0.5}, {0, 8.2}}, 
     PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"KO\"", "\"WT\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.7405511776663013`*^9, 3.7405523736982393`*^9, 3.740555159165304*^9, 
   3.740614925682191*^9, 3.7406153453929625`*^9, 3.740616462231656*^9, 
   3.740636856371529*^9, 3.74063808302807*^9, 3.7406383277465615`*^9, 
   3.7406991079280424`*^9, 3.740699163322239*^9, 3.7406994310149946`*^9, 
   3.7406995089122453`*^9, {3.7406996021614237`*^9, 3.740699611919465*^9}, 
   3.7406996510095353`*^9, 3.740700152945814*^9, 3.74070084786335*^9, 
   3.7407010296300697`*^9, 3.7407011286278434`*^9, 3.7407015791098347`*^9, 
   3.7407023901708593`*^9, 3.740702789952761*^9, 3.7407030707844543`*^9, 
   3.7407032089382973`*^9, 3.7407036424474583`*^9, 3.7407038444678135`*^9, 
   3.740704421169626*^9, 3.740704653953235*^9, 3.7407048051331005`*^9, 
   3.740705207643008*^9, 3.74070536796449*^9, 3.7407058466588545`*^9, 
   3.740706027484374*^9, 3.7407065837189517`*^9, 3.7407078122487097`*^9, 
   3.7407084104473605`*^9, 3.740708518758351*^9, {3.740708853051338*^9, 
   3.740708873768174*^9}, 3.740709086287348*^9, 3.7407094893608556`*^9, 
   3.740709555645372*^9, {3.7407096242698927`*^9, 3.7407096442223277`*^9}, 
   3.740709920686013*^9, 3.740710016906982*^9, 3.7407106968965764`*^9, 
   3.740711648170647*^9, 3.740711804233321*^9, 3.740982518554555*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"5aa285dd-7a6e-4ee9-9920-752d289f5867"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cumulative", " ", "Probability", " ", "Density"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"tStart", "=", 
  "Now"}], "\[IndentingNewLine]", "\"\<this part takes a long time, ca.1 \
min\>\"", "\[IndentingNewLine]", 
 RowBox[{"cumDensityWT", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        RowBox[{"P", "[", 
         RowBox[{"KO", ",", "V"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"V", ",", 
          SubscriptBox["V", "min"], ",", "w"}], "}"}]}], "]"}], ",", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        RowBox[{"P", "[", 
         RowBox[{"WT", ",", "V"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"V", ",", 
          SubscriptBox["V", "min"], ",", "w"}], "}"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", 
      SubscriptBox["V", "min"], ",", "0.5"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<KO\>\"", ",", "\"\<WT\>\""}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"tEnd", "=", "Now"}], "\[IndentingNewLine]", 
 RowBox[{"tEnd", "-", "tStart"}]}], "Input",
 CellChangeTimes->{{3.740552003266856*^9, 3.740552067251124*^9}, {
   3.740552143588358*^9, 3.740552212122916*^9}, {3.7405522774977245`*^9, 
   3.7405523012609863`*^9}, {3.740552348377102*^9, 3.74055235673813*^9}, {
   3.7405528123147783`*^9, 3.7405528163568087`*^9}, {3.7405535208326035`*^9, 
   3.740553527202613*^9}, {3.7405543646586547`*^9, 3.7405543660326653`*^9}, {
   3.740554487960444*^9, 3.7405545106725054`*^9}, {3.740636707304931*^9, 
   3.740636798065192*^9}, {3.7406377678784056`*^9, 3.740637794235468*^9}, 
   3.740637949273572*^9, {3.7406990574856825`*^9, 3.7406990704397163`*^9}, 
   3.7407116344582233`*^9},
 CellLabel->"In[45]:=",ExpressionUUID->"352b894b-8394-4281-bd4f-b7de943bcb4b"],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Thu 19 Jul 2018 18:48:47\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", 
        StyleBox["9.`", NumberMarks -> False, StripOnInput -> False]}], 
      FontColor -> GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{
          "2018", ",", "7", ",", "19", ",", "18", ",", "48", ",", 
           "47.581834`8.430016153863782"}], "}"}], ",", "\"Instant\"", ",", 
       "\"Gregorian\"", ",", "9.`"}], "]"}]},
  "DateObject",
  Editable->False]], "Output",
 CellChangeTimes->{3.740637802113494*^9, 3.7406378384356236`*^9, 
  3.740639116978448*^9, 3.7406991687812862`*^9, 3.7406996942576327`*^9, 
  3.7407022930450883`*^9, 3.740703770102483*^9, 3.740707352406702*^9, 
  3.740708786673221*^9, 3.740710699829382*^9, 3.7407116516806536`*^9, 
  3.740711809942931*^9, 3.740982527631907*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"cafd8b16-c6b8-4e45-8671-988623a6d58a"],

Cell[BoxData["\<\"this part takes a long time, ca.1 min\"\>"], "Output",
 CellChangeTimes->{3.740637802113494*^9, 3.7406378384356236`*^9, 
  3.740639116978448*^9, 3.7406991687812862`*^9, 3.7406996942576327`*^9, 
  3.7407022930450883`*^9, 3.740703770102483*^9, 3.740707352406702*^9, 
  3.740708786673221*^9, 3.740710699829382*^9, 3.7407116516806536`*^9, 
  3.740711809942931*^9, 3.740982527643764*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"965df8ae-3fb1-4c62-93a5-824e25de52da"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVzms0lAkAxnHGaGub7ehi6a5xbdg6UhbFU6qVSWazSmW3bOkiViRmSqZy
IpdiE4UyxaJkJuVWQigNY+S4380buQ0zryNDWFM7++E5//P79qw7fs7lJEVN
TW2fav+XR3F42HfpOlZfy/orc+asXXOvYrlAdB1G0fMnvHv3YEFFWjxbNww7
rPsr+BqHceHK10haYRjEZfP+YTt4gTlXcMFyPBxSoyBNQ/FFfJk0YEadjsSD
kaVdVW+j8KuUMmnuGgPzZbb640EPoH7mWEb5j/FYT91o+GZpDmLatpkbVPIQ
ajz1yEdcAY34179tOpoOvjbHK4Mhxu8TrK3MHVmoH4mzKR1ugL7OlK1PzDMk
R3uWBVq04nlL/xFu+QvwnWPpjfUdoFLc0sW++aimnZ5Y6NqDIZFmZbzWS2zw
7TZKsfgIKnPvGu2wIshHmCU3LvfikNny8OQNJbAvHd++raQPQ8IQk7anb2Cp
zx78WvUJodzYeodb5bj8hEpZXNAPPjP9TiZRgXCNr9p6KQNQnKcqPFa+w9sv
P/HKPQbhVmvSleJfCd3rweECvSFcC/AWJFa8x8GC3aFa4iGIgmZWjc0K8cvg
s8gc92GYZe9dWu1cjUg93jXByDD4W6WZc9Ei2CZxrUI9pdijZFbkfaqB5iX4
WfRIkU0TC0221KIq1dTU33EEppy7XjPnPiC8TZZmkTmCqmVGd5ze1+Emvcat
gDKK8nA1gVK9HofXiIu3uYxCjaHU3MyrRxFDpHUqeRR1A+5p2Q4NMDwfoaju
G0U2y+OHhoEGcDl/GO9bJ4N2o7D459uNWN2+8uUSDxlOBJccC7Fugtldmnhl
kgxljW6Nfq1NSNZaln+7RoYs+wMRGVeb4RxHPRo8J0OaxzQtYm0LEk2b/CXG
cnAzGDcci1vAnPZ7mM6SY5hStsvJsxWuEaypSbYcfy6aqZ9Tb0NU6vP1a+/L
cXpTwiOS34ZOJcNa+EaOy9Q2uxindkxVTduRPXIEKh830qTtcA/QCHk0K8e/
i7qyauM6oHdSktiqQ+LvujyWjXknjrtvZJ8zJ5GXSVpJuztRK1rgyd1Loijj
lQ47rAt56k6eV0+QqHMxeZ9L74bTqe5j9zgk/HVnCzZ+6MaS3YxeegwJ+k3/
wCM+PUi1lH+vm0ripRGH4TlfAufCtzrZuSQ6Oz7Sc15IkJIu0H5WSWLh1jHp
YxYBD7NXgbHNJCjRq5heLgTikhJ8m1We7nR8yjhAQK+0/uDyFhL9l9LPCo4Q
IO4FTKapXPL68GjuSQJm+ye8C1pJ+NhUykqDCTxRLrFvayfxwTpprOkxgR3B
tvmLekhURgpZCU8JnC9clbZf5dcdEzkHBQTolM9X4lXOvOjs15FLoPPM7YUr
JCS4RRrjklICYd6GJwwIEhusfT9LmwjcFPF1LHtJGETed8luJcDbrvsdR+UV
HdW5Ph0Ettx4N1ik8ryL+gFjEgJXikeDbPtISF61TyikBCoV6l07P5Fonj/P
tVBGwN541ClM5ZpDFvnsMQJif6scocqF07cuzCoINB5YvNuxnwR/T3Fz8RcC
dWQGJ0rltMThzSGzBEZ4zx+IVU4c1k6wUxJY0LflBW2ARKzVzslv31R/N9kU
7lP5P5mWhlE=
          "]]}, Annotation[#, "Charting`Private`Tag$36030#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVx3k4lAkAx/Exjqct27MdEoVNsghRylXzK+mhyRO5oy0dKoxknKmkco1y
5UjtJg1mNlc5okgZMblyRW5vOWJk5k2xyVE7+8f3+T6fDSd8bN2pFArliLj/
n061uD8UEg6VgZV7+ygutI4P0wr59eGY5Ycp7aUa4RceOzlobQQOR8nbEJqW
8L/ygyVbGoHlhq7SRhecQV944r9jKhLCwN2BVvIe+DajRo85w8Lwa88geZsQ
aHe219iXssBv4ew2V76EEyVhUJGOgXSnnYT+1GU0M/sNStgxuJsg4/R3exiy
yCSVwYEbKDi4yaCKHQ4bAXVG3z4OK80NZFwLbyKy7rHPAjsOOg1TfPvKWFRw
j07wp+LwOytEL6oxDuqnywnX+Hgwbexu7wtKQOiU0aiZewK+c7aFHOfegv25
zy2MjERsGZrQrzS5DYmzx7Kr1iQjtXtD/YfEDFQNxG0L3JMM62tFN+mTGQi1
e8HbzEhGw3vNcprFA8zRlAZTecnI33TdvfbHA3yR61vjzUhB5s8Afz3/TIy8
coxWqE6FgpR9e0YQB3UqB72Y3neQFDvfsrQ3D3FdO/XVatIhoap+5LHXE0gm
l9ttPZqF6z7lOfOUahz5am1K3/MQJcImPUp2PTbK/7uLEVeAKMdMHWNqGx53
jriEVhUiJd5d7XZrB6SoTlmN50rgHM4wNHjejbF66Zrk38rgb++6KsmuH1L0
A8pyEc+w8fT7RRNvAs7aCpF3dZ+j1Y1rc3/PB4zxL2t05byAaucjJaVbQ7gW
Gt9qEVsFya9WEbSXw8ijZyVxCB5oG4cvDo2NYJopNe227hUUXyTMJQyNwqlJ
o++ebw3M0wKDzbo/4qqfV34arxadrcgMKxxDfeD39eQcH4oDvIqKs+PQzj2w
qu5gHcpMDuW4rRcgz1TAWbhRj9+WausMFgtguUjnFQ83gKG7b62m5QRyZRv5
Gtub8MNnxQHHxglsDk71+O7zBrqahaxNJp/werV6klVtMxzKFCVmOJ9QFUnJ
X5RohVZNI3uWOgmK1qK0QXor5mpXNck7TKJ51JWda9EGh03pm2U4k8i1dvu1
bbQNBcuWGWZNTEKunV9hmNgOvvcQa6euECcvPj922fgt2J6ya709hXjZ7tR+
/t1b2OowEu/cE+KhmUN0dlgHFtKUlba3CsF2m5WNVunEkXETitW8EKHZWlH7
Kzph7rc+WlJVhHHqS3OrU++w7vPSaKalCMeXf29dkOhCoQWdZuYhwpmtKRmi
vC4wy3MS21giXJLqosVZdYNCWDRxs0UIWOS2ywq64afA9ah+IcL88r6HTbd6
0DVaMFvdJUJCc7G1iX4vTlcn9OsJRSjmiIwE/b24OlV9NJJK4ln2U/mgiD4E
/3nNsEKORLOtRm2Raj+0ZihZpuokfNfOPdnyph8j3aafynaQUL3pG+DCGMDZ
f2LSP5qTKFMP1jq1ZBC5Ql5qzSESvT3vVR8VDmJr2rxazlESy0xJAdeagBrT
I63OgwT1xnq6hy2B3cWrXWbFnu3dn6PlQEDq+P1lGp4kRkKyPPNdCEiqedGi
xH5efvhTkTuBcW74sLkXCYZJzWTlRQKhiXN6lQwSb4zvkG+5BLTo+6lsHxI1
LL51Sg4B6ppTjS1il/d8feSYT6C7RDFiUWzOhYPne4oIfHRiNjifJxH6THJq
sJJAwB9e95b7ktA1PvdF8JaA9scQjyAmCTXWX7a57wj4Vy/SssRW7KkrYvQQ
uCIXJN0mtsyFjX7kIAHV4JPuWn4kBp92f50WEChSeOnbL3bHEhn70kkCZpzE
liX+JBqct5UEkQSmlaOUt4tdOhvrPzdN4OzI5/hYsfMsKzoqvhE4ve180TOx
2WnjBpfnCHxhavBHxU4bl0uhLRK4pazSuCKARLzR3pmfPwlEPzrM2yX2f+3g
6wc=
          "]]}, Annotation[#, "Charting`Private`Tag$36030#2"]& ]}}, {}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
     True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"KO\"", "\"WT\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.740637802113494*^9, 3.7406378384356236`*^9, 
  3.740639116978448*^9, 3.7406991687812862`*^9, 3.7406996942576327`*^9, 
  3.7407022930450883`*^9, 3.740703770102483*^9, 3.740707352406702*^9, 
  3.740708786673221*^9, 3.740710699829382*^9, 3.7407116516806536`*^9, 
  3.740711809942931*^9, 3.740982560649683*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"9b739fef-e3bb-4e3e-8ec6-2af93b19d24c"],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Thu 19 Jul 2018 18:49:20\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", 
        StyleBox["9.`", NumberMarks -> False, StripOnInput -> False]}], 
      FontColor -> GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{
          "2018", ",", "7", ",", "19", ",", "18", ",", "49", ",", 
           "20.634004`8.067158494100614"}], "}"}], ",", "\"Instant\"", ",", 
       "\"Gregorian\"", ",", "9.`"}], "]"}]},
  "DateObject",
  Editable->False]], "Output",
 CellChangeTimes->{3.740637802113494*^9, 3.7406378384356236`*^9, 
  3.740639116978448*^9, 3.7406991687812862`*^9, 3.7406996942576327`*^9, 
  3.7407022930450883`*^9, 3.740703770102483*^9, 3.740707352406702*^9, 
  3.740708786673221*^9, 3.740710699829382*^9, 3.7407116516806536`*^9, 
  3.740711809942931*^9, 3.740982560659213*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"d8201ffa-ac93-447c-b187-0c273fbd457c"],

Cell[BoxData[
 TemplateBox[{"33.052170000000004`","\"s\"","seconds","\"Seconds\""},
  "Quantity"]], "Output",
 CellChangeTimes->{3.740637802113494*^9, 3.7406378384356236`*^9, 
  3.740639116978448*^9, 3.7406991687812862`*^9, 3.7406996942576327`*^9, 
  3.7407022930450883`*^9, 3.740703770102483*^9, 3.740707352406702*^9, 
  3.740708786673221*^9, 3.740710699829382*^9, 3.7407116516806536`*^9, 
  3.740711809942931*^9, 3.740982560666416*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"39996141-c738-400a-b004-fa039df845e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Spine", " ", "Elimination", " ", "Rate"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"K", "=", "4"}], ";"}], "                     ", 
  RowBox[{"(*", " ", 
   RowBox[{"Days", " ", "FP", " ", "equation", " ", "is", " ", "solved"}], 
   " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"para0", "=", "param"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Parameter", " ", "for", " ", "initial", " ", "distribution"}], 
   " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"para1", "=", "param"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Parameter", " ", "for", " ", "evolution"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"init", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "[", "0", "]"}], "\[Equal]", 
        RowBox[{"P", "[", 
         RowBox[{"para0", ",", 
          RowBox[{"A", "[", "i", "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "mx"}], "}"}]}], "]"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"solveFPE", "[", 
   RowBox[{
    RowBox[{"\[Sigma]", "[", "para1", "]"}], ",", 
    RowBox[{"\[Mu]", "[", "para1", "]"}], ",", "init", ",", "K", ",", "2"}], 
   "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Persist", "[", "t_", "]"}], ":=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"A", "[", "i", "]"}], ",", 
         RowBox[{"Evaluate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "i", "]"}], "[", "t", "]"}], "/.", 
           "\[InvisibleSpace]", "sol1"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "mx"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "List", " ", "of", " ", "spine", " ", "volume", " ", "and", " ", 
    "probability", " ", "density"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Rm", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"ii", "=", "1"}], "mx"], 
       RowBox[{"dV", " ", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "ii", "]"}], "[", "t", "]"}], "/.", 
          "\[InvisibleSpace]", "sol1"}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "K"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Rates", " ", "of", " ", "remaining", " ", "spines", " ", "per", " ", 
    "initial", " ", "count"}], 
   "*)"}]}], "\n", "\"\<Elimination rates of spines in one, two, and four \
days after identification of spines\>\"", "\[IndentingNewLine]", 
 RowBox[{"Flatten", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "-", 
      RowBox[{"Rm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
    ",", 
    FractionBox[
     RowBox[{
      RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "-", 
      RowBox[{"Rm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
     RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
    ",", 
    FractionBox[
     RowBox[{
      RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "-", 
      RowBox[{"Rm", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]}], 
     RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
   "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.444008958421875*^9, 3.444009082703125*^9}, {
   3.444009131234375*^9, 3.44400915265625*^9}, {3.444009194015625*^9, 
   3.444009232515625*^9}, {3.44400940359375*^9, 3.44400940659375*^9}, 
   3.444010044046875*^9, {3.444021275125*^9, 3.444021302140625*^9}, {
   3.44410193015625*^9, 3.444101931125*^9}, 3.444187222140625*^9, {
   3.4443529217782683`*^9, 3.4443531806532683`*^9}, {3.4443620660595183`*^9, 
   3.4443620667157683`*^9}, {3.444362100325143*^9, 3.444362288731393*^9}, {
   3.6979170882108846`*^9, 3.6979171368090467`*^9}, {3.697917241579583*^9, 
   3.697917247235607*^9}, {3.6979200172943587`*^9, 3.6979200181483626`*^9}, 
   3.6979215468159976`*^9, {3.6990696871347237`*^9, 3.6990696877687283`*^9}, 
   3.7135903527229633`*^9, {3.7136510070037737`*^9, 3.7136510098762875`*^9}, {
   3.7405489423529196`*^9, 3.740548992409083*^9}, 3.74054903775821*^9, {
   3.7405491252654357`*^9, 3.7405492103826485`*^9}, {3.740549309450843*^9, 
   3.740549399062062*^9}, {3.7406136950087366`*^9, 3.740613699536761*^9}, {
   3.740613814861322*^9, 3.7406138166453304`*^9}, 3.7406140061240163`*^9, {
   3.7406145588410034`*^9, 3.7406145598910046`*^9}, {3.7406993918199186`*^9, 
   3.7406993944899225`*^9}, {3.7407057768643312`*^9, 
   3.7407058212308097`*^9}, {3.740706478637167*^9, 3.7407065163112335`*^9}, {
   3.74071014665241*^9, 3.7407101726420555`*^9}, {3.740710293932269*^9, 
   3.7407102950398703`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"5c0b332e-e998-4511-adcb-70fdf5be820d"],

Cell[BoxData["\<\"Elimination rates of spines in one, two, and four days \
after identification of spines\"\>"], "Output",
 CellChangeTimes->{3.74071170068034*^9, 3.7407118651202283`*^9, 
  3.740982652854459*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"59e34a20-2ab1-48e5-9c83-461f99f35f15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.04121334668908757`", ",", "0.07065072085048119`", ",", 
   "0.12006392179304635`"}], "}"}]], "Output",
 CellChangeTimes->{3.74071170068034*^9, 3.7407118651202283`*^9, 
  3.740982652863578*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"7800d26a-6e2f-44ae-9794-4614c73bd4db"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<Elimination rates of spines in one, two, and four days after \
identification of spines (WT)\>\"", " "}]], "Input",
 CellChangeTimes->{{3.7407108467816396`*^9, 3.740710849418044*^9}, {
  3.740710897154128*^9, 
  3.740710899790533*^9}},ExpressionUUID->"e0f133e5-8215-4819-99c6-\
ac3b39c591e9"],

Cell[BoxData["\<\"Elimination rates of spines in one, two, and four days \
after identification of spines (WT)\"\>"], "Output",
 CellChangeTimes->{
  3.740636850473418*^9, 3.7406380772309647`*^9, 3.7406383223344727`*^9, 
   3.740700839080535*^9, 3.740701022547657*^9, 3.7407011189558263`*^9, 
   3.7407015739618254`*^9, 3.7407023855532513`*^9, 3.7407027859279547`*^9, 
   3.740703066728448*^9, 3.7407032048666897`*^9, 3.740703638126251*^9, 
   3.7407038403962064`*^9, 3.740704416770419*^9, 3.740704648774026*^9, 
   3.740704799657491*^9, 3.7407052025573997`*^9, 3.7407053631128817`*^9, 
   3.7407058388276405`*^9, 3.740706021509564*^9, 3.740706579366544*^9, 
   3.7407078082863026`*^9, 3.740708406110553*^9, 3.740708514702344*^9, {
   3.7407088491045313`*^9, 3.7407088698213673`*^9}, 3.7407090822469406`*^9, 
   3.7407094853048487`*^9, 3.740709551589365*^9, {3.740709619465084*^9, 
   3.7407096401663203`*^9}, 3.740709916645606*^9, 3.740710008982168*^9, 
   3.740710749531069*^9, 
   3.74071170075834*^9},ExpressionUUID->"11e8ea14-2e29-41ec-9b83-\
4bc03a139471"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Spine", " ", "Elimination", " ", "Rate"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"param", "=", "KO"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"para0", "=", "param"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Parameter", " ", "for", " ", "initial", " ", "distribution"}], 
   " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"para1", "=", "param"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Parameter", " ", "for", " ", "evolution"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"init", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"p", "[", "i", "]"}], "[", "0", "]"}], "\[Equal]", 
        RowBox[{"P", "[", 
         RowBox[{"para0", ",", 
          RowBox[{"A", "[", "i", "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "mx"}], "}"}]}], "]"}], "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"solveFPE", "[", 
   RowBox[{
    RowBox[{"\[Sigma]", "[", "para1", "]"}], ",", 
    RowBox[{"\[Mu]", "[", "para1", "]"}], ",", "init", ",", "K", ",", "2"}], 
   "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Persist", "[", "t_", "]"}], ":=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"A", "[", "i", "]"}], ",", 
         RowBox[{"Evaluate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"p", "[", "i", "]"}], "[", "t", "]"}], "/.", 
           "\[InvisibleSpace]", "sol1"}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "mx"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "List", " ", "of", " ", "spine", " ", "volume", " ", "and", " ", 
    "probability", " ", "density"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Rm", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"ii", "=", "1"}], "mx"], 
       RowBox[{"dV", " ", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"p", "[", "ii", "]"}], "[", "t", "]"}], "/.", 
          "\[InvisibleSpace]", "sol1"}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "K"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "Rates", " ", "of", " ", "remaining", " ", "spines", " ", "per", " ", 
    "initial", " ", "count"}], 
   "*)"}]}], "\n", "\"\<Elimination rates of spines in one, two, and four \
days after identification of spines (KO)\>\"", "\[IndentingNewLine]", 
 RowBox[{"Flatten", "[", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "-", 
      RowBox[{"Rm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
    ",", 
    FractionBox[
     RowBox[{
      RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "-", 
      RowBox[{"Rm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
     RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
    ",", 
    FractionBox[
     RowBox[{
      RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "-", 
      RowBox[{"Rm", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]}], 
     RowBox[{"Rm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
   "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.444008958421875*^9, 3.444009082703125*^9}, {
   3.444009131234375*^9, 3.44400915265625*^9}, {3.444009194015625*^9, 
   3.444009232515625*^9}, {3.44400940359375*^9, 3.44400940659375*^9}, 
   3.444010044046875*^9, {3.444021275125*^9, 3.444021302140625*^9}, {
   3.44410193015625*^9, 3.444101931125*^9}, 3.444187222140625*^9, {
   3.4443529217782683`*^9, 3.4443531806532683`*^9}, {3.4443620660595183`*^9, 
   3.4443620667157683`*^9}, {3.444362100325143*^9, 3.444362288731393*^9}, {
   3.6979170882108846`*^9, 3.6979171368090467`*^9}, {3.697917241579583*^9, 
   3.697917247235607*^9}, {3.6979200172943587`*^9, 3.6979200181483626`*^9}, 
   3.6979215468159976`*^9, {3.6990696871347237`*^9, 3.6990696877687283`*^9}, 
   3.7135903527229633`*^9, {3.7136510070037737`*^9, 3.7136510098762875`*^9}, {
   3.7405489423529196`*^9, 3.740548992409083*^9}, 3.74054903775821*^9, {
   3.7405491252654357`*^9, 3.7405492103826485`*^9}, {3.740549309450843*^9, 
   3.740549399062062*^9}, {3.7406136950087366`*^9, 3.740613699536761*^9}, {
   3.740613814861322*^9, 3.7406138166453304`*^9}, 3.7406140061240163`*^9, {
   3.7406145588410034`*^9, 3.7406145598910046`*^9}, {3.7406993918199186`*^9, 
   3.7406993944899225`*^9}, {3.7407057768643312`*^9, 
   3.7407058212308097`*^9}, {3.740706478637167*^9, 3.7407065163112335`*^9}, {
   3.74071014665241*^9, 3.7407101726420555`*^9}, {3.740710293932269*^9, 
   3.7407102950398703`*^9}, {3.7407108855165076`*^9, 3.740710905702943*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"ebab8ed0-401a-49b0-97e3-74743e23b361"],

Cell[BoxData["\<\"Elimination rates of spines in one, two, and four days \
after identification of spines (KO)\"\>"], "Output",
 CellChangeTimes->{3.7407117019907417`*^9, 3.740711867335432*^9, 
  3.74098259702983*^9, 3.7409826712225323`*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"bc2c3082-61ad-4707-9648-24b96cc77fd6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.04121334668908757`", ",", "0.07065072085048119`", ",", 
   "0.12006392179304635`"}], "}"}]], "Output",
 CellChangeTimes->{3.7407117019907417`*^9, 3.740711867335432*^9, 
  3.74098259702983*^9, 3.740982671231914*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"85d4dadf-cf98-408c-8804-48cb779e8241"]
}, Open  ]]
},
WindowSize->{759, 835},
WindowMargins->{{285, Automatic}, {Automatic, 57}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (2018\:5e743\
\:670812\:65e5)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 46308, 948, 2149, "Input",ExpressionUUID->"6c255fb8-e875-4d6c-a224-26c2a0c3bec6"],
Cell[CellGroupData[{
Cell[46891, 972, 3143, 71, 458, "Input",ExpressionUUID->"2163fde9-a6d5-4789-afdf-273ea69ba2c6"],
Cell[50037, 1045, 1408, 19, 34, "Output",ExpressionUUID->"4952214c-8ae0-4da8-9350-a82991a830a3"],
Cell[51448, 1066, 1526, 23, 34, "Output",ExpressionUUID->"5c61c9c6-6a55-4bc2-99d4-6b1102f9d06b"],
Cell[52977, 1091, 1524, 23, 34, "Output",ExpressionUUID->"80a300cc-9353-421f-93b5-95605b36fdb0"],
Cell[54504, 1116, 1398, 19, 34, "Output",ExpressionUUID->"246d1c91-16a3-41a3-a06c-d756fb9cc373"],
Cell[55905, 1137, 1553, 26, 37, "Output",ExpressionUUID->"baa44a71-bd93-487b-b4ae-e59e9396cc2c"],
Cell[57461, 1165, 1553, 26, 37, "Output",ExpressionUUID->"89ba804c-41a8-4cf0-bc2d-ba4816cdc545"],
Cell[59017, 1193, 1433, 20, 34, "Output",ExpressionUUID->"5141e67b-8cce-4956-aa87-faa653463050"],
Cell[60453, 1215, 26955, 496, 249, "Output",ExpressionUUID->"5aa285dd-7a6e-4ee9-9920-752d289f5867"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87445, 1716, 1963, 45, 253, "Input",ExpressionUUID->"352b894b-8394-4281-bd4f-b7de943bcb4b"],
Cell[89411, 1763, 966, 19, 43, "Output",ExpressionUUID->"cafd8b16-c6b8-4e45-8671-988623a6d58a"],
Cell[90380, 1784, 479, 6, 34, "Output",ExpressionUUID->"965df8ae-3fb1-4c62-93a5-824e25de52da"],
Cell[90862, 1792, 15801, 314, 241, "Output",ExpressionUUID->"9b739fef-e3bb-4e3e-8ec6-2af93b19d24c"],
Cell[106666, 2108, 966, 19, 43, "Output",ExpressionUUID->"d8201ffa-ac93-447c-b187-0c273fbd457c"],
Cell[107635, 2129, 516, 8, 36, "Output",ExpressionUUID->"39996141-c738-400a-b004-fa039df845e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108188, 2142, 5228, 129, 389, "Input",ExpressionUUID->"5c0b332e-e998-4511-adcb-70fdf5be820d"],
Cell[113419, 2273, 291, 4, 56, "Output",ExpressionUUID->"59e34a20-2ab1-48e5-9c83-461f99f35f15"],
Cell[113713, 2279, 316, 7, 34, "Output",ExpressionUUID->"7800d26a-6e2f-44ae-9794-4614c73bd4db"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114066, 2291, 320, 6, 52, "Input",ExpressionUUID->"e0f133e5-8215-4819-99c6-ac3b39c591e9"],
Cell[114389, 2299, 1062, 16, 56, "Output",ExpressionUUID->"11e8ea14-2e29-41ec-9b83-4bc03a139471"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115488, 2320, 5132, 125, 389, "Input",ExpressionUUID->"ebab8ed0-401a-49b0-97e3-74743e23b361"],
Cell[120623, 2447, 320, 4, 56, "Output",ExpressionUUID->"bc2c3082-61ad-4707-9648-24b96cc77fd6"],
Cell[120946, 2453, 338, 7, 68, "Output",ExpressionUUID->"85d4dadf-cf98-408c-8804-48cb779e8241"]
}, Open  ]]
}
]
*)

